""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.cube.schemas import models

""" Cube API Schema
"""


"""
API: CreateCubeDeployment

创建Cube的Deployment
"""


class CreateCubeDeploymentRequestSchema(schema.RequestSchema):
    """CreateCubeDeployment - 创建Cube的Deployment"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CpuPlatform": fields.Str(required=False, dump_to="CpuPlatform"),
        "Deployment": fields.Str(required=True, dump_to="Deployment"),
        "KubeConfig": fields.Str(required=False, dump_to="KubeConfig"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateCubeDeploymentResponseSchema(schema.ResponseSchema):
    """CreateCubeDeployment - 创建Cube的Deployment"""

    fields = {
        "Deployment": fields.Str(required=False, load_from="Deployment"),
        "DeploymentId": fields.Str(required=True, load_from="DeploymentId"),
    }


"""
API: CreateCubePod

创建Pod
"""


class CreateCubePodRequestSchema(schema.RequestSchema):
    """CreateCubePod - 创建Pod"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "CpuPlatform": fields.Str(required=False, dump_to="CpuPlatform"),
        "Group": fields.Str(required=False, dump_to="Group"),
        "KubeConfig": fields.Str(required=False, dump_to="KubeConfig"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "Pod": fields.Str(required=True, dump_to="Pod"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateCubePodResponseSchema(schema.ResponseSchema):
    """CreateCubePod - 创建Pod"""

    fields = {
        "CubeId": fields.Str(required=False, load_from="CubeId"),
        "Pod": fields.Str(required=True, load_from="Pod"),
    }


"""
API: DeleteCubeDeployment

删除Cube的Deployment
"""


class DeleteCubeDeploymentRequestSchema(schema.RequestSchema):
    """DeleteCubeDeployment - 删除Cube的Deployment"""

    fields = {
        "DeploymentId": fields.Str(required=True, dump_to="DeploymentId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DeleteCubeDeploymentResponseSchema(schema.ResponseSchema):
    """DeleteCubeDeployment - 删除Cube的Deployment"""

    fields = {}


"""
API: DeleteCubePod

删除Pod
"""


class DeleteCubePodRequestSchema(schema.RequestSchema):
    """DeleteCubePod - 删除Pod"""

    fields = {
        "CubeId": fields.Str(required=False, dump_to="CubeId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ReleaseEIP": fields.Bool(required=False, dump_to="ReleaseEIP"),
        "Uid": fields.Str(required=False, dump_to="Uid"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DeleteCubePodResponseSchema(schema.ResponseSchema):
    """DeleteCubePod - 删除Pod"""

    fields = {}


"""
API: GetCubeDeployment

获取Deployment的详细信息
"""


class GetCubeDeploymentRequestSchema(schema.RequestSchema):
    """GetCubeDeployment - 获取Deployment的详细信息"""

    fields = {
        "DeploymentId": fields.Str(required=True, dump_to="DeploymentId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class GetCubeDeploymentResponseSchema(schema.ResponseSchema):
    """GetCubeDeployment - 获取Deployment的详细信息"""

    fields = {
        "Deployment": fields.Str(required=True, load_from="Deployment"),
    }


"""
API: GetCubeExecToken

获取登录容器的token
"""


class GetCubeExecTokenRequestSchema(schema.RequestSchema):
    """GetCubeExecToken - 获取登录容器的token"""

    fields = {
        "ContainerName": fields.Str(required=True, dump_to="ContainerName"),
        "CubeId": fields.Str(required=False, dump_to="CubeId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Uid": fields.Str(required=False, dump_to="Uid"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class GetCubeExecTokenResponseSchema(schema.ResponseSchema):
    """GetCubeExecToken - 获取登录容器的token"""

    fields = {
        "TerminalUrl": fields.Str(required=False, load_from="TerminalUrl"),
        "Token": fields.Str(required=True, load_from="Token"),
    }


"""
API: GetCubeExtendInfo

获取Cube的额外信息
"""


class GetCubeExtendInfoRequestSchema(schema.RequestSchema):
    """GetCubeExtendInfo - 获取Cube的额外信息"""

    fields = {
        "CubeIds": fields.Str(required=True, dump_to="CubeIds"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class GetCubeExtendInfoResponseSchema(schema.ResponseSchema):
    """GetCubeExtendInfo - 获取Cube的额外信息"""

    fields = {
        "ExtendInfo": fields.List(
            models.CubeExtendInfoSchema(), required=True, load_from="ExtendInfo"
        ),
    }


"""
API: GetCubeMetrics

获取Cube实例（Pod，PodX，Deploy等）监控数据时间序列
"""


class GetCubeMetricsRequestSchema(schema.RequestSchema):
    """GetCubeMetrics - 获取Cube实例（Pod，PodX，Deploy等）监控数据时间序列"""

    fields = {
        "BeginTime": fields.Int(required=True, dump_to="BeginTime"),
        "ContainerName": fields.Str(required=True, dump_to="ContainerName"),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "MetricName": fields.List(fields.Str()),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ResourceId": fields.Str(required=True, dump_to="ResourceId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class GetCubeMetricsResponseSchema(schema.ResponseSchema):
    """GetCubeMetrics - 获取Cube实例（Pod，PodX，Deploy等）监控数据时间序列"""

    fields = {
        "DataSets": fields.List(
            models.MetricDataSetSchema(), required=False, load_from="DataSets"
        ),
        "Message": fields.Str(required=False, load_from="Message"),
    }


"""
API: GetCubePod

获取Pod的详细信息
"""


class GetCubePodRequestSchema(schema.RequestSchema):
    """GetCubePod - 获取Pod的详细信息"""

    fields = {
        "CubeId": fields.Str(required=False, dump_to="CubeId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Uid": fields.Str(required=False, dump_to="Uid"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class GetCubePodResponseSchema(schema.ResponseSchema):
    """GetCubePod - 获取Pod的详细信息"""

    fields = {
        "Pod": fields.Str(required=True, load_from="Pod"),
    }


"""
API: GetCubePrice

获取cube的价格
"""


class GetCubePriceRequestSchema(schema.RequestSchema):
    """GetCubePrice - 获取cube的价格"""

    fields = {
        "ChargeType": fields.Str(required=True, dump_to="ChargeType"),
        "Count": fields.Str(required=True, dump_to="Count"),
        "Cpu": fields.Str(required=True, dump_to="Cpu"),
        "Mem": fields.Str(required=True, dump_to="Mem"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=True, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class GetCubePriceResponseSchema(schema.ResponseSchema):
    """GetCubePrice - 获取cube的价格"""

    fields = {
        "OriginalPrice": fields.Int(required=True, load_from="OriginalPrice"),
        "Price": fields.Int(required=True, load_from="Price"),
    }


"""
API: GetCubeToken

获取Cube的token，可用于terminal登录、log获取
"""


class GetCubeTokenRequestSchema(schema.RequestSchema):
    """GetCubeToken - 获取Cube的token，可用于terminal登录、log获取"""

    fields = {
        "ContainerName": fields.Str(required=True, dump_to="ContainerName"),
        "CubeId": fields.Str(required=False, dump_to="CubeId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Uid": fields.Str(required=False, dump_to="Uid"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class GetCubeTokenResponseSchema(schema.ResponseSchema):
    """GetCubeToken - 获取Cube的token，可用于terminal登录、log获取"""

    fields = {
        "Token": fields.Str(required=True, load_from="Token"),
    }


"""
API: ListCubeDeployment

获取Cube的Deployment列表
"""


class ListCubeDeploymentRequestSchema(schema.RequestSchema):
    """ListCubeDeployment - 获取Cube的Deployment列表"""

    fields = {
        "Limit": fields.Int(required=True, dump_to="Limit"),
        "Offset": fields.Int(required=True, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ListCubeDeploymentResponseSchema(schema.ResponseSchema):
    """ListCubeDeployment - 获取Cube的Deployment列表"""

    fields = {
        "Deployments": fields.List(
            fields.Str(), required=True, load_from="Deployments"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: ListCubePod

获取Pods列表
"""


class ListCubePodRequestSchema(schema.RequestSchema):
    """ListCubePod - 获取Pods列表"""

    fields = {
        "DeploymentId": fields.Str(required=False, dump_to="DeploymentId"),
        "Group": fields.Str(required=False, dump_to="Group"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ListCubePodResponseSchema(schema.ResponseSchema):
    """ListCubePod - 获取Pods列表"""

    fields = {
        "Pods": fields.List(fields.Str(), required=True, load_from="Pods"),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: ModifyCubeExtendInfo

修改Cube额外信息
"""


class ModifyCubeExtendInfoRequestSchema(schema.RequestSchema):
    """ModifyCubeExtendInfo - 修改Cube额外信息"""

    fields = {
        "CubeId": fields.Str(required=True, dump_to="CubeId"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ModifyCubeExtendInfoResponseSchema(schema.ResponseSchema):
    """ModifyCubeExtendInfo - 修改Cube额外信息"""

    fields = {}


"""
API: ModifyCubeTag

修改业务组名字
"""


class ModifyCubeTagRequestSchema(schema.RequestSchema):
    """ModifyCubeTag - 修改业务组名字"""

    fields = {
        "CubeId": fields.Str(required=True, dump_to="CubeId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Tag": fields.Str(required=True, dump_to="Tag"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ModifyCubeTagResponseSchema(schema.ResponseSchema):
    """ModifyCubeTag - 修改业务组名字"""

    fields = {
        "CubeId": fields.Str(required=True, load_from="CubeId"),
    }


"""
API: RebootCubePod

重启Cube Pod
"""


class RebootCubePodRequestSchema(schema.RequestSchema):
    """RebootCubePod - 重启Cube Pod"""

    fields = {
        "CubeId": fields.Str(required=True, dump_to="CubeId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class RebootCubePodResponseSchema(schema.ResponseSchema):
    """RebootCubePod - 重启Cube Pod"""

    fields = {}


"""
API: RenewCubePod

更新Pod
"""


class RenewCubePodRequestSchema(schema.RequestSchema):
    """RenewCubePod - 更新Pod"""

    fields = {
        "CubeId": fields.Str(required=True, dump_to="CubeId"),
        "Pod": fields.Str(required=True, dump_to="Pod"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class RenewCubePodResponseSchema(schema.ResponseSchema):
    """RenewCubePod - 更新Pod"""

    fields = {
        "Pod": fields.Str(required=True, load_from="Pod"),
    }


"""
API: UpdateCubeDeployment

更新Deployment
"""


class UpdateCubeDeploymentRequestSchema(schema.RequestSchema):
    """UpdateCubeDeployment - 更新Deployment"""

    fields = {
        "Deployment": fields.Str(required=True, dump_to="Deployment"),
        "DeploymentId": fields.Str(required=True, dump_to="DeploymentId"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class UpdateCubeDeploymentResponseSchema(schema.ResponseSchema):
    """UpdateCubeDeployment - 更新Deployment"""

    fields = {
        "Deployment": fields.Str(required=False, load_from="Deployment"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class PhoneInfoSchema(schema.ResponseSchema):
    """PhoneInfo - 号码信息"""

    fields = {
        "Phone": fields.Str(required=False, load_from="Phone"),
    }


class VerifyInfoSchema(schema.ResponseSchema):
    """VerifyInfo - 检测结果信息"""

    fields = {
        "VerifyResult": fields.Str(required=False, load_from="VerifyResult"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class NodeListSchema(schema.ResponseSchema):
    """NodeList - 虚拟机资源id列表"""

    fields = {
        "NodeId": fields.Str(required=False, load_from="NodeId"),
    }


class RuleInfoSchema(schema.ResponseSchema):
    """RuleInfo - 防火墙规则"""

    fields = {
        "Action": fields.Str(required=True, load_from="Action"),
        "Port": fields.Str(required=True, load_from="Port"),
        "Priority": fields.Str(required=True, load_from="Priority"),
        "ProtocolType": fields.Str(required=True, load_from="ProtocolType"),
        "Remark": fields.Str(required=True, load_from="Remark"),
        "SrcIp": fields.Str(required=True, load_from="SrcIp"),
    }


class FirewallInfoSchema(schema.ResponseSchema):
    """FirewallInfo - 防火墙信息"""

    fields = {
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "FirewallId": fields.Str(required=True, load_from="FirewallId"),
        "Name": fields.Str(required=True, load_from="Name"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "ResourceCount": fields.Int(required=True, load_from="ResourceCount"),
        "Rule": fields.List(RuleInfoSchema()),
        "Type": fields.Str(required=True, load_from="Type"),
    }


class ResourceInfoSchema(schema.ResponseSchema):
    """ResourceInfo - 绑定防火墙的资源信息"""

    fields = {
        "Name": fields.Str(required=True, load_from="Name"),
        "PublicIpList": fields.List(fields.Str()),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "ResourceId": fields.Str(required=True, load_from="ResourceId"),
        "State": fields.Int(required=True, load_from="State"),
    }


class CfgDictListSchema(schema.ResponseSchema):
    """CfgDictList - 容器配置字典列表"""

    fields = {
        "MountPath": fields.Str(required=False, load_from="MountPath"),
        "Name": fields.Str(required=False, load_from="Name"),
        "ResourceId": fields.Str(required=False, load_from="ResourceId"),
    }


class EnvListSchema(schema.ResponseSchema):
    """EnvList - 容器环境变量列表"""

    fields = {
        "Key": fields.Str(required=False, load_from="Key"),
        "Value": fields.Str(required=False, load_from="Value"),
    }


class IpListSchema(schema.ResponseSchema):
    """IpList - 容器组外网ip列表"""

    fields = {
        "Ip": fields.Str(required=False, load_from="Ip"),
        "Isp": fields.Str(required=False, load_from="Isp"),
    }


class ImageListSchema(schema.ResponseSchema):
    """ImageList - 容器组镜像密钥列表"""

    fields = {
        "ImageKey": fields.Str(required=False, load_from="ImageKey"),
        "StoreAddr": fields.Str(required=False, load_from="StoreAddr"),
        "UserName": fields.Str(required=False, load_from="UserName"),
    }


class DockerInfoSchema(schema.ResponseSchema):
    """DockerInfo - 容器信息"""

    fields = {
        "Args": fields.Str(required=False, load_from="Args"),
        "CfgDictList": fields.List(CfgDictListSchema()),
        "Command": fields.Str(required=False, load_from="Command"),
        "CpuCores": fields.Float(required=False, load_from="CpuCores"),
        "EnvList": fields.List(EnvListSchema()),
        "ImageName": fields.Str(required=False, load_from="ImageName"),
        "MemSize": fields.Float(required=False, load_from="MemSize"),
        "Name": fields.Str(required=False, load_from="Name"),
        "State": fields.Int(required=False, load_from="State"),
        "WorkDir": fields.Str(required=False, load_from="WorkDir"),
    }


class StorVolumeInfoSchema(schema.ResponseSchema):
    """StorVolumeInfo - 容器组存储卷信息"""

    fields = {
        "DiskSize": fields.Int(required=False, load_from="DiskSize"),
        "MountPoint": fields.Str(required=False, load_from="MountPoint"),
        "Name": fields.Str(required=False, load_from="Name"),
        "ResourceId": fields.Str(required=False, load_from="ResourceId"),
    }


class HolderListSchema(schema.ResponseSchema):
    """HolderList - 容器组信息"""

    fields = {
        "City": fields.Str(required=False, load_from="City"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "DockerCount": fields.Int(required=False, load_from="DockerCount"),
        "DockerInfo": fields.List(DockerInfoSchema()),
        "ExpireTime": fields.Int(required=False, load_from="ExpireTime"),
        "FirewallId": fields.Str(required=False, load_from="FirewallId"),
        "HolderName": fields.Str(required=False, load_from="HolderName"),
        "IdcId": fields.Str(required=False, load_from="IdcId"),
        "ImageList": fields.List(ImageListSchema()),
        "InnerIp": fields.Str(required=False, load_from="InnerIp"),
        "IpList": fields.List(IpListSchema()),
        "NetLimit": fields.Int(required=False, load_from="NetLimit"),
        "OcName": fields.Str(required=False, load_from="OcName"),
        "ProductType": fields.Str(required=False, load_from="ProductType"),
        "Province": fields.Str(required=False, load_from="Province"),
        "ResourceId": fields.Str(required=False, load_from="ResourceId"),
        "RestartStrategy": fields.Int(
            required=False, load_from="RestartStrategy"
        ),
        "State": fields.Int(required=False, load_from="State"),
        "StorVolumeCount": fields.Int(
            required=False, load_from="StorVolumeCount"
        ),
        "StorVolumeInfo": fields.List(StorVolumeInfoSchema()),
        "SubnetId": fields.Str(required=False, load_from="SubnetId"),
        "Type": fields.Int(required=False, load_from="Type"),
    }


class IdcInfoSchema(schema.ResponseSchema):
    """IdcInfo - 机房信息"""

    fields = {
        "City": fields.Str(required=False, load_from="City"),
        "IdcId": fields.Str(required=False, load_from="IdcId"),
        "Isp": fields.Str(required=False, load_from="Isp"),
        "MaxNodeCnt": fields.Int(required=False, load_from="MaxNodeCnt"),
        "Name": fields.Str(required=False, load_from="Name"),
        "Province": fields.Str(required=False, load_from="Province"),
        "Type": fields.Int(required=False, load_from="Type"),
    }


class SubnetInfoSchema(schema.ResponseSchema):
    """SubnetInfo - 子网信息"""

    fields = {
        "AvailableIPCnt": fields.Int(required=True, load_from="AvailableIPCnt"),
        "CIDR": fields.Str(required=True, load_from="CIDR"),
        "Comment": fields.Str(required=True, load_from="Comment"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "IdcId": fields.Str(required=True, load_from="IdcId"),
        "SubnetId": fields.Str(required=True, load_from="SubnetId"),
        "SubnetName": fields.Str(required=True, load_from="SubnetName"),
        "TotalIpCnt": fields.Int(required=True, load_from="TotalIpCnt"),
    }


class NodeIpListSchema(schema.ResponseSchema):
    """NodeIpList - 虚拟机外网ip列表"""

    fields = {
        "Ip": fields.Str(required=False, load_from="Ip"),
        "Isp": fields.Str(required=False, load_from="Isp"),
        "IspName": fields.Str(required=False, load_from="IspName"),
    }


class NodeInfoSchema(schema.ResponseSchema):
    """NodeInfo - 节点信息"""

    fields = {
        "ChargeType": fields.Int(required=False, load_from="ChargeType"),
        "City": fields.Str(required=False, load_from="City"),
        "CoreNum": fields.Int(required=False, load_from="CoreNum"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "DiskSize": fields.Int(required=False, load_from="DiskSize"),
        "ExpiredTime": fields.Int(required=False, load_from="ExpiredTime"),
        "FirewallId": fields.Str(required=False, load_from="FirewallId"),
        "IdcId": fields.Str(required=False, load_from="IdcId"),
        "ImageName": fields.Str(required=False, load_from="ImageName"),
        "InnerIps": fields.List(fields.Str()),
        "MemSize": fields.Int(required=False, load_from="MemSize"),
        "NetLimit": fields.Int(required=False, load_from="NetLimit"),
        "NodeId": fields.Str(required=False, load_from="NodeId"),
        "NodeIpList": fields.List(NodeIpListSchema()),
        "NodeName": fields.Str(required=False, load_from="NodeName"),
        "OcName": fields.Str(required=False, load_from="OcName"),
        "ProductType": fields.Str(required=False, load_from="ProductType"),
        "Province": fields.Str(required=False, load_from="Province"),
        "State": fields.Int(required=False, load_from="State"),
        "SysDiskSize": fields.Int(required=False, load_from="SysDiskSize"),
        "Type": fields.Int(required=False, load_from="Type"),
    }


class NodeIspListSchema(schema.ResponseSchema):
    """NodeIspList - 节点运营商列表"""

    fields = {
        "City": fields.Str(required=False, load_from="City"),
        "IdcName": fields.Str(required=False, load_from="IdcName"),
        "IspName": fields.Str(required=False, load_from="IspName"),
        "LineType": fields.Str(required=False, load_from="LineType"),
        "Province": fields.Str(required=False, load_from="Province"),
    }


class MonitorInfoSchema(schema.ResponseSchema):
    """MonitorInfo - 监控信息"""

    fields = {
        "TimeStamp": fields.Int(required=True, load_from="TimeStamp"),
        "Value": fields.Int(required=True, load_from="Value"),
    }


class MetricisDataSetSchema(schema.ResponseSchema):
    """MetricisDataSet - 监控数据"""

    fields = {
        "CPUUtilization": fields.List(MonitorInfoSchema()),
        "MemUtilization": fields.List(MonitorInfoSchema()),
        "NICIn": fields.List(MonitorInfoSchema()),
        "NICOut": fields.List(MonitorInfoSchema()),
        "NetPacketIn": fields.List(MonitorInfoSchema()),
        "NetPacketOut": fields.List(MonitorInfoSchema()),
    }


class ResourceSetSchema(schema.ResponseSchema):
    """ResourceSet - 受到影响的资源列表"""

    fields = {
        "NodeId": fields.Str(required=False, load_from="NodeId"),
        "OuterIps": fields.List(fields.Str()),
    }


class IDCCutInfoSchema(schema.ResponseSchema):
    """IDCCutInfo - 机房割接信息"""

    fields = {
        "City": fields.Str(required=False, load_from="City"),
        "CutType": fields.Str(required=False, load_from="CutType"),
        "EndTime": fields.Int(required=False, load_from="EndTime"),
        "IDCName": fields.Str(required=False, load_from="IDCName"),
        "Province": fields.Str(required=False, load_from="Province"),
        "ResourceSet": fields.List(ResourceSetSchema()),
        "StartTime": fields.Int(required=False, load_from="StartTime"),
    }


class DataSetSchema(schema.ResponseSchema):
    """DataSet - 监控信息集合"""

    fields = {
        "CPUUtilization": fields.List(MonitorInfoSchema()),
        "DiskReadOps": fields.List(MonitorInfoSchema()),
        "DiskWriteOps": fields.List(MonitorInfoSchema()),
        "IORead": fields.List(MonitorInfoSchema()),
        "IOWrite": fields.List(MonitorInfoSchema()),
        "MemUtilization": fields.List(MonitorInfoSchema()),
        "NICIn": fields.List(MonitorInfoSchema()),
        "NICOut": fields.List(MonitorInfoSchema()),
        "NetPacketIn": fields.List(MonitorInfoSchema()),
        "NetPacketOut": fields.List(MonitorInfoSchema()),
    }


class DeployImageInfoSchema(schema.ResponseSchema):
    """DeployImageInfo - 镜像部署信息"""

    fields = {
        "IdcId": fields.Str(required=False, load_from="IdcId"),
        "State": fields.Int(required=False, load_from="State"),
    }


class ImageInfoSchema(schema.ResponseSchema):
    """ImageInfo - 镜像详情"""

    fields = {
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "DeployInfoList": fields.List(DeployImageInfoSchema()),
        "Gpu": fields.Int(required=False, load_from="Gpu"),
        "ImageDesc": fields.Str(required=False, load_from="ImageDesc"),
        "ImageId": fields.Str(required=False, load_from="ImageId"),
        "ImageName": fields.Str(required=False, load_from="ImageName"),
        "ImageSize": fields.Int(required=False, load_from="ImageSize"),
        "ImageType": fields.Int(required=False, load_from="ImageType"),
        "OcType": fields.Str(required=False, load_from="OcType"),
        "State": fields.Int(required=False, load_from="State"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class TagSetSchema(schema.ResponseSchema):
    """TagSet - Tag详细信息"""

    fields = {
        "Digest": fields.Str(required=False, load_from="Digest"),
        "TagName": fields.Str(required=True, load_from="TagName"),
        "UpdateTime": fields.Str(required=True, load_from="UpdateTime"),
    }


class RepoSetSchema(schema.ResponseSchema):
    """RepoSet - 镜像仓库"""

    fields = {
        "CreateTime": fields.Str(required=True, load_from="CreateTime"),
        "Description": fields.Str(required=True, load_from="Description"),
        "IsOutSide": fields.Str(required=True, load_from="IsOutSide"),
        "IsShared": fields.Str(required=True, load_from="IsShared"),
        "RepoName": fields.Str(required=True, load_from="RepoName"),
        "UpdateTime": fields.Str(required=True, load_from="UpdateTime"),
    }


class ImageSetSchema(schema.ResponseSchema):
    """ImageSet - 镜像信息"""

    fields = {
        "CreateTime": fields.Str(required=True, load_from="CreateTime"),
        "ImageName": fields.Str(required=True, load_from="ImageName"),
        "LatestTag": fields.Str(required=True, load_from="LatestTag"),
        "PullCount": fields.Int(required=True, load_from="PullCount"),
        "RepoName": fields.Str(required=True, load_from="RepoName"),
        "UpdateTime": fields.Str(required=True, load_from="UpdateTime"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.uk8s.schemas import models

""" UK8S API Schema
"""


"""
API: AddUK8SExistingUHost

将预先创建好的云主机加入到UK8S集群，需要注意的是，该云主机依然会执行重装系统的操作。
"""


class AddUK8SExistingUHostRequestSchema(schema.RequestSchema):
    """AddUK8SExistingUHost - 将预先创建好的云主机加入到UK8S集群，需要注意的是，该云主机依然会执行重装系统的操作。"""

    fields = {
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "DisableSchedule": fields.Bool(
            required=False, dump_to="DisableSchedule"
        ),
        "ImageId": fields.Str(required=False, dump_to="ImageId"),
        "InitScript": fields.Str(required=False, dump_to="InitScript"),
        "Labels": fields.Str(required=False, dump_to="Labels"),
        "MaxPods": fields.Int(required=False, dump_to="MaxPods"),
        "Password": fields.Str(required=True, dump_to="Password"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "UHostId": fields.Str(required=True, dump_to="UHostId"),
        "UserData": fields.Str(required=False, dump_to="UserData"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class AddUK8SExistingUHostResponseSchema(schema.ResponseSchema):
    """AddUK8SExistingUHost - 将预先创建好的云主机加入到UK8S集群，需要注意的是，该云主机依然会执行重装系统的操作。"""

    fields = {
        "Message": fields.Str(required=False, load_from="Message"),
    }


"""
API: AddUK8SNodeGroup

添加UK8S节点池
"""


class AddUK8SNodeGroupRequestSchema(schema.RequestSchema):
    """AddUK8SNodeGroup - 添加UK8S节点池"""

    fields = {
        "BootDiskType": fields.Str(required=False, dump_to="BootDiskType"),
        "CPU": fields.Int(required=False, dump_to="CPU"),
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "DataDiskSize": fields.Int(required=False, dump_to="DataDiskSize"),
        "DataDiskType": fields.Str(required=False, dump_to="DataDiskType"),
        "GPU": fields.Int(required=False, dump_to="GPU"),
        "GpuType": fields.Str(required=False, dump_to="GpuType"),
        "ImageId": fields.Str(required=False, dump_to="ImageId"),
        "MachineType": fields.Str(required=False, dump_to="MachineType"),
        "Mem": fields.Int(required=False, dump_to="Mem"),
        "MinimalCpuPlatform": fields.Str(
            required=False, dump_to="MinimalCpuPlatform"
        ),
        "NodeGroupName": fields.Str(required=True, dump_to="NodeGroupName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class AddUK8SNodeGroupResponseSchema(schema.ResponseSchema):
    """AddUK8SNodeGroup - 添加UK8S节点池"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
        "NodeGroupId": fields.Str(required=True, load_from="NodeGroupId"),
    }


"""
API: AddUK8SPHostNode

为UK8S集群添加一台或多台物理云主机类型的节点。
"""


class AddUK8SPHostNodeRequestSchema(schema.RequestSchema):
    """AddUK8SPHostNode - 为UK8S集群添加一台或多台物理云主机类型的节点。"""

    fields = {
        "ChargeType": fields.Str(required=True, dump_to="ChargeType"),
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "Count": fields.Int(required=True, dump_to="Count"),
        "DisableSchedule": fields.Bool(
            required=False, dump_to="DisableSchedule"
        ),
        "ImageId": fields.Str(required=False, dump_to="ImageId"),
        "InitScript": fields.Str(required=False, dump_to="InitScript"),
        "Labels": fields.Str(required=False, dump_to="Labels"),
        "MaxPods": fields.Int(required=False, dump_to="MaxPods"),
        "NIC": fields.Str(required=False, dump_to="NIC"),
        "Password": fields.Str(required=True, dump_to="Password"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Raid": fields.Str(required=False, dump_to="Raid"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "Type": fields.Str(required=False, dump_to="Type"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class AddUK8SPHostNodeResponseSchema(schema.ResponseSchema):
    """AddUK8SPHostNode - 为UK8S集群添加一台或多台物理云主机类型的节点。"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: AddUK8SUHostNode

为UK8S集群添加一台Node节点，机型类型为云主机
"""


class AddUK8SUHostNodeRequestSchema(schema.RequestSchema):
    """AddUK8SUHostNode - 为UK8S集群添加一台Node节点，机型类型为云主机"""

    fields = {
        "BootDiskType": fields.Str(required=False, dump_to="BootDiskType"),
        "CPU": fields.Int(required=True, dump_to="CPU"),
        "ChargeType": fields.Str(required=True, dump_to="ChargeType"),
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "Count": fields.Int(required=True, dump_to="Count"),
        "DataDiskSize": fields.Int(required=False, dump_to="DataDiskSize"),
        "DataDiskType": fields.Str(required=False, dump_to="DataDiskType"),
        "DisableSchedule": fields.Bool(
            required=False, dump_to="DisableSchedule"
        ),
        "GPU": fields.Int(required=False, dump_to="GPU"),
        "GpuType": fields.Str(required=False, dump_to="GpuType"),
        "ImageId": fields.Str(required=False, dump_to="ImageId"),
        "InitScript": fields.Str(required=False, dump_to="InitScript"),
        "IsolationGroup": fields.Str(required=False, dump_to="IsolationGroup"),
        "Labels": fields.Str(required=False, dump_to="Labels"),
        "MachineType": fields.Str(required=False, dump_to="MachineType"),
        "MaxPods": fields.Int(required=False, dump_to="MaxPods"),
        "Mem": fields.Int(required=True, dump_to="Mem"),
        "MinmalCpuPlatform": fields.Str(
            required=False, dump_to="MinmalCpuPlatform"
        ),
        "Password": fields.Str(required=True, dump_to="Password"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "UserData": fields.Str(required=False, dump_to="UserData"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class AddUK8SUHostNodeResponseSchema(schema.ResponseSchema):
    """AddUK8SUHostNode - 为UK8S集群添加一台Node节点，机型类型为云主机"""

    fields = {
        "Message": fields.Str(
            required=True, load_from="Message"
        ),  # Deprecated, will be removed at 1.0
        "NodeIds": fields.List(
            fields.Str(), required=False, load_from="NodeIds"
        ),
    }


"""
API: CreateUK8SClusterV2

创建UK8S集群
"""


class CreateUK8SClusterV2ParamKubeProxySchema(schema.RequestSchema):
    """CreateUK8SClusterV2ParamKubeProxy -"""

    fields = {
        "Mode": fields.Str(required=False, dump_to="Mode"),
    }


class CreateUK8SClusterV2ParamMasterSchema(schema.RequestSchema):
    """CreateUK8SClusterV2ParamMaster -"""

    fields = {
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateUK8SClusterV2ParamNodesSchema(schema.RequestSchema):
    """CreateUK8SClusterV2ParamNodes -"""

    fields = {
        "BootDiskType": fields.Str(required=False, dump_to="BootDiskType"),
        "CPU": fields.Int(required=True, dump_to="CPU"),
        "Count": fields.Int(required=True, dump_to="Count"),
        "DataDiskSize": fields.Int(required=False, dump_to="DataDiskSize"),
        "DataDiskType": fields.Str(required=False, dump_to="DataDiskType"),
        "GPU": fields.Int(required=False, dump_to="GPU"),
        "GpuType": fields.Str(required=False, dump_to="GpuType"),
        "IsolationGroup": fields.Str(required=False, dump_to="IsolationGroup"),
        "Labels": fields.Str(required=False, dump_to="Labels"),
        "MachineType": fields.Str(required=True, dump_to="MachineType"),
        "MaxPods": fields.Int(required=False, dump_to="MaxPods"),
        "Mem": fields.Int(required=True, dump_to="Mem"),
        "MinmalCpuPlatform": fields.Str(
            required=False, dump_to="MinmalCpuPlatform"
        ),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateUK8SClusterV2RequestSchema(schema.RequestSchema):
    """CreateUK8SClusterV2 - 创建UK8S集群"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "ClusterName": fields.Str(required=True, dump_to="ClusterName"),
        "ExternalApiServer": fields.Str(
            required=False, dump_to="ExternalApiServer"
        ),
        "ImageId": fields.Str(required=False, dump_to="ImageId"),
        "InitScript": fields.Str(required=False, dump_to="InitScript"),
        "K8sVersion": fields.Str(required=False, dump_to="K8sVersion"),
        "KubeProxy": CreateUK8SClusterV2ParamKubeProxySchema(
            required=False, dump_to="KubeProxy"
        ),
        "Master": fields.List(CreateUK8SClusterV2ParamMasterSchema()),
        "MasterBootDiskType": fields.Str(
            required=False, dump_to="MasterBootDiskType"
        ),
        "MasterCPU": fields.Int(required=True, dump_to="MasterCPU"),
        "MasterDataDiskSize": fields.Int(
            required=False, dump_to="MasterDataDiskSize"
        ),
        "MasterDataDiskType": fields.Str(
            required=False, dump_to="MasterDataDiskType"
        ),
        "MasterIsolationGroup": fields.Str(
            required=False, dump_to="MasterIsolationGroup"
        ),
        "MasterMachineType": fields.Str(
            required=True, dump_to="MasterMachineType"
        ),
        "MasterMem": fields.Int(required=True, dump_to="MasterMem"),
        "MasterMinmalCpuPlatform": fields.Str(
            required=False, dump_to="MasterMinmalCpuPlatform"
        ),
        "Nodes": fields.List(CreateUK8SClusterV2ParamNodesSchema()),
        "Password": fields.Str(required=True, dump_to="Password"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ServiceCIDR": fields.Str(required=True, dump_to="ServiceCIDR"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "UserData": fields.Str(required=False, dump_to="UserData"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
    }


class CreateUK8SClusterV2ResponseSchema(schema.ResponseSchema):
    """CreateUK8SClusterV2 - 创建UK8S集群"""

    fields = {
        "ClusterId": fields.Str(required=True, load_from="ClusterId"),
    }


"""
API: DelUK8SCluster

删除UK8S集群
"""


class DelUK8SClusterRequestSchema(schema.RequestSchema):
    """DelUK8SCluster - 删除UK8S集群"""

    fields = {
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ReleaseUDisk": fields.Bool(required=False, dump_to="ReleaseUDisk"),
    }


class DelUK8SClusterResponseSchema(schema.ResponseSchema):
    """DelUK8SCluster - 删除UK8S集群"""

    fields = {}


"""
API: DelUK8SClusterNodeV2

删除集群中的Node节点，删除前务必先将其中的Pod驱逐。
"""


class DelUK8SClusterNodeV2RequestSchema(schema.RequestSchema):
    """DelUK8SClusterNodeV2 - 删除集群中的Node节点，删除前务必先将其中的Pod驱逐。"""

    fields = {
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "NodeId": fields.Str(required=True, dump_to="NodeId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "ReleaseDataUDisk": fields.Bool(
            required=False, dump_to="ReleaseDataUDisk"
        ),
    }


class DelUK8SClusterNodeV2ResponseSchema(schema.ResponseSchema):
    """DelUK8SClusterNodeV2 - 删除集群中的Node节点，删除前务必先将其中的Pod驱逐。"""

    fields = {
        "Message": fields.Str(required=False, load_from="Message"),
    }


"""
API: DescribeUK8SCluster

获取集群信息
"""


class DescribeUK8SClusterRequestSchema(schema.RequestSchema):
    """DescribeUK8SCluster - 获取集群信息"""

    fields = {
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeUK8SClusterResponseSchema(schema.ResponseSchema):
    """DescribeUK8SCluster - 获取集群信息"""

    fields = {
        "ApiServer": fields.Str(required=False, load_from="ApiServer"),
        "CACert": fields.Str(required=False, load_from="CACert"),
        "ClusterDomain": fields.Str(required=False, load_from="ClusterDomain"),
        "ClusterId": fields.Str(required=True, load_from="ClusterId"),
        "ClusterName": fields.Str(required=True, load_from="ClusterName"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "EtcdCert": fields.Str(required=False, load_from="EtcdCert"),
        "EtcdKey": fields.Str(required=False, load_from="EtcdKey"),
        "ExternalApiServer": fields.Str(
            required=False, load_from="ExternalApiServer"
        ),
        "KubeProxy": models.KubeProxySchema(),
        "MasterCount": fields.Int(required=True, load_from="MasterCount"),
        "MasterList": fields.List(
            models.UhostInfoSchema(), required=False, load_from="MasterList"
        ),
        "MasterResourceStatus": fields.Str(
            required=False, load_from="MasterResourceStatus"
        ),
        "NodeCount": fields.Int(required=False, load_from="NodeCount"),
        "NodeList": fields.List(
            models.UhostInfoSchema(), required=False, load_from="NodeList"
        ),
        "PodCIDR": fields.Str(required=True, load_from="PodCIDR"),
        "ServiceCIDR": fields.Str(required=True, load_from="ServiceCIDR"),
        "Status": fields.Str(required=False, load_from="Status"),
        "SubnetId": fields.Str(required=True, load_from="SubnetId"),
        "VPCId": fields.Str(required=True, load_from="VPCId"),
        "Version": fields.Str(required=False, load_from="Version"),
    }


"""
API: DescribeUK8SImage

获取UK8S支持的Node节点操作系统，可基于该操作系统制定自定义镜像
"""


class DescribeUK8SImageRequestSchema(schema.RequestSchema):
    """DescribeUK8SImage - 获取UK8S支持的Node节点操作系统，可基于该操作系统制定自定义镜像"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUK8SImageResponseSchema(schema.ResponseSchema):
    """DescribeUK8SImage - 获取UK8S支持的Node节点操作系统，可基于该操作系统制定自定义镜像"""

    fields = {
        "ImageSet": fields.List(
            models.ImageInfoSchema(), required=False, load_from="ImageSet"
        ),
        "Message": fields.Str(required=True, load_from="Message"),
        "PHostImageSet": fields.List(
            models.ImageInfoSchema(), required=False, load_from="PHostImageSet"
        ),
    }


"""
API: DescribeUK8SNode

用于获取 UK8S 节点详情
"""


class DescribeUK8SNodeRequestSchema(schema.RequestSchema):
    """DescribeUK8SNode - 用于获取 UK8S 节点详情"""

    fields = {
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class DescribeUK8SNodeResponseSchema(schema.ResponseSchema):
    """DescribeUK8SNode - 用于获取 UK8S 节点详情"""

    fields = {
        "Action": fields.Str(required=True, load_from="Action"),
        "AllocatedPodCount": fields.Int(
            required=True, load_from="AllocatedPodCount"
        ),
        "Annotations": fields.List(
            fields.Str(), required=True, load_from="Annotations"
        ),
        "CPUCapacity": fields.Str(required=True, load_from="CPUCapacity"),
        "CPULimits": fields.Str(required=True, load_from="CPULimits"),
        "CPULimitsFraction": fields.Str(
            required=True, load_from="CPULimitsFraction"
        ),
        "CPURequests": fields.Str(required=True, load_from="CPURequests"),
        "CPURequestsFraction": fields.Str(
            required=True, load_from="CPURequestsFraction"
        ),
        "Conditions": fields.List(
            models.K8SNodeConditionSchema(),
            required=True,
            load_from="Conditions",
        ),
        "ContainerImages": fields.List(
            fields.Str(), required=True, load_from="ContainerImages"
        ),
        "ContainerRuntimeVersion": fields.Str(
            required=True, load_from="ContainerRuntimeVersion"
        ),
        "CreationTimestamp": fields.Int(
            required=True, load_from="CreationTimestamp"
        ),
        "Hostname": fields.Str(required=True, load_from="Hostname"),
        "InternalIP": fields.Str(required=True, load_from="InternalIP"),
        "KernelVersion": fields.Str(required=True, load_from="KernelVersion"),
        "KubeProxyVersion": fields.Str(
            required=True, load_from="KubeProxyVersion"
        ),
        "KubeletVersion": fields.Str(required=True, load_from="KubeletVersion"),
        "Labels": fields.List(fields.Str(), required=True, load_from="Labels"),
        "MemoryCapacity": fields.Str(required=True, load_from="MemoryCapacity"),
        "MemoryLimits": fields.Str(required=True, load_from="MemoryLimits"),
        "MemoryLimitsFraction": fields.Str(
            required=True, load_from="MemoryLimitsFraction"
        ),
        "MemoryRequests": fields.Str(required=True, load_from="MemoryRequests"),
        "MemoryRequestsFraction": fields.Str(
            required=True, load_from="MemoryRequestsFraction"
        ),
        "Message": fields.Str(required=True, load_from="Message"),
        "Name": fields.Str(required=True, load_from="Name"),
        "OSImage": fields.Str(required=True, load_from="OSImage"),
        "PodCapacity": fields.Int(required=True, load_from="PodCapacity"),
        "ProviderID": fields.Str(required=True, load_from="ProviderID"),
        "RetCode": fields.Int(required=True, load_from="RetCode"),
        "Taints": fields.List(fields.Str(), required=False, load_from="Taints"),
        "Unschedulable": fields.Bool(required=True, load_from="Unschedulable"),
    }


"""
API: ListUK8SClusterNodeV2

获取UK8S集群节点信息
"""


class ListUK8SClusterNodeV2RequestSchema(schema.RequestSchema):
    """ListUK8SClusterNodeV2 - 获取UK8S集群节点信息"""

    fields = {
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class ListUK8SClusterNodeV2ResponseSchema(schema.ResponseSchema):
    """ListUK8SClusterNodeV2 - 获取UK8S集群节点信息"""

    fields = {
        "NodeSet": fields.List(
            models.NodeInfoV2Schema(), required=True, load_from="NodeSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: ListUK8SClusterV2

获取UK8S集群列表信息
"""


class ListUK8SClusterV2RequestSchema(schema.RequestSchema):
    """ListUK8SClusterV2 - 获取UK8S集群列表信息"""

    fields = {
        "ClusterId": fields.Str(required=False, dump_to="ClusterId"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class ListUK8SClusterV2ResponseSchema(schema.ResponseSchema):
    """ListUK8SClusterV2 - 获取UK8S集群列表信息"""

    fields = {
        "ClusterCount": fields.Int(required=True, load_from="ClusterCount"),
        "ClusterSet": fields.List(
            models.ClusterSetSchema(), required=False, load_from="ClusterSet"
        ),
    }


"""
API: ListUK8SNodeGroup

列出UK8S节点池
"""


class ListUK8SNodeGroupRequestSchema(schema.RequestSchema):
    """ListUK8SNodeGroup - 列出UK8S节点池"""

    fields = {
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(
            required=False, dump_to="Zone"
        ),  # Deprecated, will be removed at 1.0
    }


class ListUK8SNodeGroupResponseSchema(schema.ResponseSchema):
    """ListUK8SNodeGroup - 列出UK8S节点池"""

    fields = {
        "NodeGroupList": fields.List(
            models.NodeGroupSetSchema(),
            required=False,
            load_from="NodeGroupList",
        ),
    }


"""
API: RemoveUK8SNodeGroup

删除UK8S节点池
"""


class RemoveUK8SNodeGroupRequestSchema(schema.RequestSchema):
    """RemoveUK8SNodeGroup - 删除UK8S节点池"""

    fields = {
        "ClusterId": fields.Str(required=True, dump_to="ClusterId"),
        "NodeGroupId": fields.Str(required=True, dump_to="NodeGroupId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(
            required=False, dump_to="Zone"
        ),  # Deprecated, will be removed at 1.0
    }


class RemoveUK8SNodeGroupResponseSchema(schema.ResponseSchema):
    """RemoveUK8SNodeGroup - 删除UK8S节点池"""

    fields = {}



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class GroupBaseInfoSchema(schema.ResponseSchema):
    """GroupBaseInfo - Group基础信息"""

    fields = {
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "GroupName": fields.Str(required=True, load_from="GroupName"),
        "Id": fields.Str(required=True, load_from="Id"),
        "Remark": fields.Str(required=True, load_from="Remark"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class BindVSInfoSchema(schema.ResponseSchema):
    """BindVSInfo - 证书绑定的vs信息"""

    fields = {
        "LBID": fields.Str(required=False, load_from="LBID"),
        "LBName": fields.Str(required=False, load_from="LBName"),
        "Port": fields.Int(required=False, load_from="Port"),
        "Protocol": fields.Str(required=False, load_from="Protocol"),
        "VSID": fields.Str(required=False, load_from="VSID"),
    }


class CertificateInfoSchema(schema.ResponseSchema):
    """CertificateInfo - 证书信息"""

    fields = {
        "CertificateContent": fields.Str(
            required=False, load_from="CertificateContent"
        ),
        "CertificateID": fields.Str(required=False, load_from="CertificateID"),
        "CertificateType": fields.Str(
            required=False, load_from="CertificateType"
        ),
        "CommonName": fields.Str(required=False, load_from="CommonName"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "ExpireTime": fields.Int(required=False, load_from="ExpireTime"),
        "Fingerprint": fields.Str(required=False, load_from="Fingerprint"),
        "Name": fields.Str(required=False, load_from="Name"),
        "Privatekey": fields.Str(required=False, load_from="Privatekey"),
        "Region": fields.Str(required=False, load_from="Region"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "SubjectAlternativeNames": fields.List(fields.Str()),
        "VSInfos": fields.List(BindVSInfoSchema()),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class DiskInfoSchema(schema.ResponseSchema):
    """DiskInfo - 磁盘信息"""

    fields = {
        "AttachResourceID": fields.Str(
            required=True, load_from="AttachResourceID"
        ),
        "ChargeType": fields.Str(required=True, load_from="ChargeType"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "DiskID": fields.Str(required=True, load_from="DiskID"),
        "DiskStatus": fields.Str(required=True, load_from="DiskStatus"),
        "DiskType": fields.Str(required=True, load_from="DiskType"),
        "ExpireTime": fields.Int(required=True, load_from="ExpireTime"),
        "Name": fields.Str(required=True, load_from="Name"),
        "Region": fields.Str(required=True, load_from="Region"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "SetType": fields.Str(required=True, load_from="SetType"),
        "Size": fields.Int(required=True, load_from="Size"),
        "Zone": fields.Str(required=True, load_from="Zone"),
    }


class EIPInfoSchema(schema.ResponseSchema):
    """EIPInfo - 外网IP信息"""

    fields = {
        "Bandwidth": fields.Int(required=False, load_from="Bandwidth"),
        "BindResourceID": fields.Str(
            required=False, load_from="BindResourceID"
        ),
        "BindResourceType": fields.Str(
            required=False, load_from="BindResourceType"
        ),
        "CanDefaultGW": fields.Int(required=False, load_from="CanDefaultGW"),
        "ChargeType": fields.Str(required=False, load_from="ChargeType"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "EIPID": fields.Str(required=False, load_from="EIPID"),
        "ExpireTime": fields.Int(required=False, load_from="ExpireTime"),
        "IP": fields.Str(required=False, load_from="IP"),
        "IPVersion": fields.Str(required=False, load_from="IPVersion"),
        "ISDefaultGW": fields.Int(required=False, load_from="ISDefaultGW"),
        "Name": fields.Str(required=False, load_from="Name"),
        "OperatorName": fields.Str(required=False, load_from="OperatorName"),
        "Region": fields.Str(required=False, load_from="Region"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "Status": fields.Str(required=False, load_from="Status"),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class ImageInfoSchema(schema.ResponseSchema):
    """ImageInfo - 镜像信息"""

    fields = {
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "ImageID": fields.Str(required=True, load_from="ImageID"),
        "ImageStatus": fields.Str(required=True, load_from="ImageStatus"),
        "ImageType": fields.Str(required=True, load_from="ImageType"),
        "Name": fields.Str(required=True, load_from="Name"),
        "OSDistribution": fields.Str(required=True, load_from="OSDistribution"),
        "OSName": fields.Str(required=True, load_from="OSName"),
        "OSType": fields.Str(required=True, load_from="OSType"),
        "Region": fields.Str(required=True, load_from="Region"),
        "SetArch": fields.Str(required=True, load_from="SetArch"),
        "Zone": fields.Str(required=True, load_from="Zone"),
    }


class LBInfoSchema(schema.ResponseSchema):
    """LBInfo - 负载均衡信息"""

    fields = {
        "AlarmTemplateID": fields.Str(
            required=True, load_from="AlarmTemplateID"
        ),
        "ChargeType": fields.Str(required=True, load_from="ChargeType"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "ExpireTime": fields.Int(required=True, load_from="ExpireTime"),
        "LBID": fields.Str(required=True, load_from="LBID"),
        "LBStatus": fields.Str(required=True, load_from="LBStatus"),
        "LBType": fields.Str(required=True, load_from="LBType"),
        "Name": fields.Str(required=True, load_from="Name"),
        "PrivateIP": fields.Str(required=False, load_from="PrivateIP"),
        "PublicIP": fields.Str(required=False, load_from="PublicIP"),
        "Region": fields.Str(required=True, load_from="Region"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "SGID": fields.Str(required=False, load_from="SGID"),
        "SubnetID": fields.Str(required=True, load_from="SubnetID"),
        "VPCID": fields.Str(required=True, load_from="VPCID"),
        "VSCount": fields.Int(required=True, load_from="VSCount"),
        "Zone": fields.Str(required=True, load_from="Zone"),
    }


class MetricSetSchema(schema.ResponseSchema):
    """MetricSet - 监控值"""

    fields = {
        "Timestamp": fields.Int(required=False, load_from="Timestamp"),
        "Value": fields.Float(required=False, load_from="Value"),
    }


class MetricInfoSchema(schema.ResponseSchema):
    """MetricInfo - 监控信息"""

    fields = {
        "Infos": fields.List(MetricSetSchema()),
        "MetricName": fields.Str(required=False, load_from="MetricName"),
    }


class NATGWInfoSchema(schema.ResponseSchema):
    """NATGWInfo - NAT网关信息"""

    fields = {
        "AlarmTemplateID": fields.Str(
            required=True, load_from="AlarmTemplateID"
        ),
        "ChargeType": fields.Str(required=True, load_from="ChargeType"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "EIP": fields.Str(required=True, load_from="EIP"),
        "ExpireTime": fields.Int(required=True, load_from="ExpireTime"),
        "NATGWID": fields.Str(required=True, load_from="NATGWID"),
        "NATGWStatus": fields.Str(required=True, load_from="NATGWStatus"),
        "Name": fields.Str(required=True, load_from="Name"),
        "Region": fields.Str(required=True, load_from="Region"),
        "Remark": fields.Str(required=True, load_from="Remark"),
        "SGID": fields.Str(required=True, load_from="SGID"),
        "SubnetID": fields.Str(required=True, load_from="SubnetID"),
        "VPCID": fields.Str(required=True, load_from="VPCID"),
        "Zone": fields.Str(required=True, load_from="Zone"),
    }


class NATGWRuleInfoSchema(schema.ResponseSchema):
    """NATGWRuleInfo - NAT网关关联的白名单资源信息"""

    fields = {
        "BindResourceID": fields.Str(required=True, load_from="BindResourceID"),
        "BindResourceType": fields.Str(
            required=True, load_from="BindResourceType"
        ),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "IP": fields.Str(required=True, load_from="IP"),
        "NATGWID": fields.Str(required=True, load_from="NATGWID"),
        "NATGWType": fields.Str(required=True, load_from="NATGWType"),
        "Name": fields.Str(required=True, load_from="Name"),
        "RuleID": fields.Str(required=True, load_from="RuleID"),
        "RuleStatus": fields.Str(required=True, load_from="RuleStatus"),
    }


class NICInfoSchema(schema.ResponseSchema):
    """NICInfo - 网卡信息"""

    fields = {
        "BindResourceID": fields.Str(required=True, load_from="BindResourceID"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "IP": fields.Str(required=True, load_from="IP"),
        "MAC": fields.Str(required=True, load_from="MAC"),
        "NICID": fields.Str(required=True, load_from="NICID"),
        "NICStatus": fields.Str(required=True, load_from="NICStatus"),
        "Name": fields.Str(required=True, load_from="Name"),
        "Region": fields.Str(required=True, load_from="Region"),
        "Remark": fields.Str(required=True, load_from="Remark"),
        "SGID": fields.Str(required=True, load_from="SGID"),
        "SubnetID": fields.Str(required=True, load_from="SubnetID"),
        "VPCID": fields.Str(required=True, load_from="VPCID"),
        "Zone": fields.Str(required=True, load_from="Zone"),
    }


class OPLogInfoSchema(schema.ResponseSchema):
    """OPLogInfo - 操作日志"""

    fields = {
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "IsSuccess": fields.Str(required=False, load_from="IsSuccess"),
        "OPLogsID": fields.Str(required=False, load_from="OPLogsID"),
        "OPName": fields.Str(required=False, load_from="OPName"),
        "OPTime": fields.Int(required=False, load_from="OPTime"),
        "OpMessage": fields.Str(required=False, load_from="OpMessage"),
        "Region": fields.Str(required=False, load_from="Region"),
        "ResourceID": fields.Str(required=False, load_from="ResourceID"),
        "ResourceType": fields.Int(required=False, load_from="ResourceType"),
        "RetCode": fields.Int(required=False, load_from="RetCode"),
        "UserEmail": fields.Str(required=False, load_from="UserEmail"),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class PhysicalIPInfoSchema(schema.ResponseSchema):
    """PhysicalIPInfo - 物理IP信息"""

    fields = {
        "BindResourceID": fields.Str(required=True, load_from="BindResourceID"),
        "BindResourceType": fields.Str(
            required=True, load_from="BindResourceType"
        ),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "IP": fields.Str(required=True, load_from="IP"),
        "Name": fields.Str(required=True, load_from="Name"),
        "OperatorName": fields.Str(required=True, load_from="OperatorName"),
        "PhysicalIPID": fields.Str(required=True, load_from="PhysicalIPID"),
        "Region": fields.Str(required=True, load_from="Region"),
        "Remark": fields.Str(required=True, load_from="Remark"),
        "Status": fields.Str(required=True, load_from="Status"),
        "UpdateTime": fields.Int(required=True, load_from="UpdateTime"),
        "Zone": fields.Str(required=True, load_from="Zone"),
    }


class RSInfoSchema(schema.ResponseSchema):
    """RSInfo - 转发规则关联的服务节点信息"""

    fields = {
        "BindResourceID": fields.Str(required=True, load_from="BindResourceID"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "IP": fields.Str(required=True, load_from="IP"),
        "LBID": fields.Str(required=True, load_from="LBID"),
        "Name": fields.Str(required=True, load_from="Name"),
        "Port": fields.Int(required=True, load_from="Port"),
        "RSID": fields.Str(required=True, load_from="RSID"),
        "RSMode": fields.Str(required=True, load_from="RSMode"),
        "RSStatus": fields.Str(required=True, load_from="RSStatus"),
        "UpdateTime": fields.Int(required=True, load_from="UpdateTime"),
        "VSID": fields.Str(required=True, load_from="VSID"),
        "Weight": fields.Int(required=True, load_from="Weight"),
    }


class RecycledResourceInfoSchema(schema.ResponseSchema):
    """RecycledResourceInfo - 回收站资源信息"""

    fields = {
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "DeleteTime": fields.Int(required=True, load_from="DeleteTime"),
        "Description": fields.Str(required=True, load_from="Description"),
        "ExpireTime": fields.Int(required=True, load_from="ExpireTime"),
        "IsAutoTerminated": fields.Bool(
            required=True, load_from="IsAutoTerminated"
        ),
        "Name": fields.Str(required=True, load_from="Name"),
        "Region": fields.Str(required=True, load_from="Region"),
        "ResourceID": fields.Str(required=True, load_from="ResourceID"),
        "ResourceType": fields.Str(required=True, load_from="ResourceType"),
        "Status": fields.Str(required=False, load_from="Status"),
        "WillTerminateTime": fields.Int(
            required=True, load_from="WillTerminateTime"
        ),
        "Zone": fields.Str(required=True, load_from="Zone"),
    }


class SGRuleInfoSchema(schema.ResponseSchema):
    """SGRuleInfo - 安全组规则信息"""

    fields = {
        "DstPort": fields.Str(required=False, load_from="DstPort"),
        "IsIn": fields.Str(required=False, load_from="IsIn"),
        "Priority": fields.Str(required=False, load_from="Priority"),
        "ProtocolType": fields.Str(required=False, load_from="ProtocolType"),
        "RuleAction": fields.Str(required=False, load_from="RuleAction"),
        "RuleID": fields.Str(required=False, load_from="RuleID"),
        "SrcIP": fields.Str(required=False, load_from="SrcIP"),
    }


class SGInfoSchema(schema.ResponseSchema):
    """SGInfo - 安全组信息"""

    fields = {
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "Name": fields.Str(required=False, load_from="Name"),
        "Region": fields.Str(required=False, load_from="Region"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "ResourceCount": fields.Int(required=False, load_from="ResourceCount"),
        "Rule": fields.List(SGRuleInfoSchema()),
        "RuleCount": fields.Int(required=False, load_from="RuleCount"),
        "SGID": fields.Str(required=False, load_from="SGID"),
        "Status": fields.Str(required=False, load_from="Status"),
        "UpdateTime": fields.Int(required=False, load_from="UpdateTime"),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class SGResourceInfoSchema(schema.ResponseSchema):
    """SGResourceInfo - 安全组绑定的资源信息"""

    fields = {
        "Name": fields.Str(required=True, load_from="Name"),
        "Region": fields.Str(required=True, load_from="Region"),
        "ResourceID": fields.Str(required=True, load_from="ResourceID"),
        "ResourceType": fields.Str(required=True, load_from="ResourceType"),
        "Zone": fields.Str(required=True, load_from="Zone"),
    }


class SnapshotInfoSchema(schema.ResponseSchema):
    """SnapshotInfo - 快照的详细信息"""

    fields = {
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "DiskID": fields.Str(required=False, load_from="DiskID"),
        "DiskType": fields.Str(required=False, load_from="DiskType"),
        "Name": fields.Str(required=False, load_from="Name"),
        "Region": fields.Str(required=False, load_from="Region"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "SnapshotID": fields.Str(required=False, load_from="SnapshotID"),
        "SnapshotStatus": fields.Str(
            required=False, load_from="SnapshotStatus"
        ),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class StorageTypeInfoSchema(schema.ResponseSchema):
    """StorageTypeInfo - 存储类型信息"""

    fields = {
        "Region": fields.Str(required=True, load_from="Region"),
        "SetArch": fields.Str(required=True, load_from="SetArch"),
        "StorageType": fields.Str(required=True, load_from="StorageType"),
        "StorageTypeAlias": fields.Str(
            required=True, load_from="StorageTypeAlias"
        ),
        "Zone": fields.Str(required=True, load_from="Zone"),
    }


class SubnetInfoSchema(schema.ResponseSchema):
    """SubnetInfo - 子网信息"""

    fields = {
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "Name": fields.Str(required=False, load_from="Name"),
        "Network": fields.Str(required=False, load_from="Network"),
        "Region": fields.Str(required=False, load_from="Region"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "State": fields.Str(required=False, load_from="State"),
        "SubnetID": fields.Str(required=False, load_from="SubnetID"),
        "UpdateTime": fields.Int(required=False, load_from="UpdateTime"),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class UserInfoSchema(schema.ResponseSchema):
    """UserInfo - 租户信息"""

    fields = {
        "Amount": fields.Float(required=False, load_from="Amount"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "Email": fields.Str(required=False, load_from="Email"),
        "PrivateKey": fields.Str(required=False, load_from="PrivateKey"),
        "PublicKey": fields.Str(required=False, load_from="PublicKey"),
        "Status": fields.Str(required=False, load_from="Status"),
        "UpdateTime": fields.Int(required=False, load_from="UpdateTime"),
        "UserID": fields.Int(required=False, load_from="UserID"),
    }


class VMDiskInfoSchema(schema.ResponseSchema):
    """VMDiskInfo - 虚拟机磁盘信息"""

    fields = {
        "DiskID": fields.Str(required=False, load_from="DiskID"),
        "Drive": fields.Str(required=False, load_from="Drive"),
        "IsElastic": fields.Str(required=False, load_from="IsElastic"),
        "Name": fields.Str(required=False, load_from="Name"),
        "Size": fields.Int(required=False, load_from="Size"),
        "Type": fields.Str(required=False, load_from="Type"),
    }


class VMIPInfoSchema(schema.ResponseSchema):
    """VMIPInfo - 虚拟机IP信息"""

    fields = {
        "IP": fields.Str(required=False, load_from="IP"),
        "IPVersion": fields.Str(required=False, load_from="IPVersion"),
        "InterfaceID": fields.Str(required=False, load_from="InterfaceID"),
        "IsElastic": fields.Str(required=False, load_from="IsElastic"),
        "MAC": fields.Str(required=False, load_from="MAC"),
        "SGID": fields.Str(required=False, load_from="SGID"),
        "SGName": fields.Str(required=False, load_from="SGName"),
        "SubnetID": fields.Str(required=False, load_from="SubnetID"),
        "SubnetName": fields.Str(required=False, load_from="SubnetName"),
        "Type": fields.Str(required=False, load_from="Type"),
        "VPCID": fields.Str(required=False, load_from="VPCID"),
        "VPCName": fields.Str(required=False, load_from="VPCName"),
    }


class VMInstanceInfoSchema(schema.ResponseSchema):
    """VMInstanceInfo - UCloudStack虚拟机信息"""

    fields = {
        "CPU": fields.Int(required=False, load_from="CPU"),
        "ChargeType": fields.Str(required=False, load_from="ChargeType"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "DiskInfos": fields.List(VMDiskInfoSchema()),
        "ExpireTime": fields.Int(required=False, load_from="ExpireTime"),
        "IPInfos": fields.List(VMIPInfoSchema()),
        "ImageID": fields.Str(required=False, load_from="ImageID"),
        "Memory": fields.Int(required=False, load_from="Memory"),
        "Name": fields.Str(required=False, load_from="Name"),
        "OSName": fields.Str(required=False, load_from="OSName"),
        "OSType": fields.Str(required=False, load_from="OSType"),
        "Region": fields.Str(required=False, load_from="Region"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "State": fields.Str(required=False, load_from="State"),
        "SubnetID": fields.Str(required=False, load_from="SubnetID"),
        "SubnetName": fields.Str(required=False, load_from="SubnetName"),
        "VMID": fields.Str(required=False, load_from="VMID"),
        "VMType": fields.Str(required=False, load_from="VMType"),
        "VMTypeAlias": fields.Str(required=False, load_from="VMTypeAlias"),
        "VPCID": fields.Str(required=False, load_from="VPCID"),
        "VPCName": fields.Str(required=False, load_from="VPCName"),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class VMTypeInfoSchema(schema.ResponseSchema):
    """VMTypeInfo - 主机机型信息"""

    fields = {
        "Region": fields.Str(required=True, load_from="Region"),
        "SetArch": fields.Str(required=True, load_from="SetArch"),
        "VMType": fields.Str(required=True, load_from="VMType"),
        "VMTypeAlias": fields.Str(required=True, load_from="VMTypeAlias"),
        "Zone": fields.Str(required=True, load_from="Zone"),
    }


class VPCInfoSchema(schema.ResponseSchema):
    """VPCInfo - VPC信息"""

    fields = {
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "Name": fields.Str(required=False, load_from="Name"),
        "Network": fields.Str(required=False, load_from="Network"),
        "Region": fields.Str(required=False, load_from="Region"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "State": fields.Str(required=False, load_from="State"),
        "SubnetCount": fields.Int(required=False, load_from="SubnetCount"),
        "SubnetInfos": fields.List(SubnetInfoSchema()),
        "UpdateTime": fields.Int(required=False, load_from="UpdateTime"),
        "VPCID": fields.Str(required=False, load_from="VPCID"),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


class VSPolicyInfoSchema(schema.ResponseSchema):
    """VSPolicyInfo - 内容转发规则信息"""

    fields = {
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "Domain": fields.Str(required=True, load_from="Domain"),
        "LBID": fields.Str(required=True, load_from="LBID"),
        "Path": fields.Str(required=True, load_from="Path"),
        "PolicyID": fields.Str(required=True, load_from="PolicyID"),
        "PolicyStatus": fields.Str(required=True, load_from="PolicyStatus"),
        "RSInfos": fields.List(RSInfoSchema()),
        "UpdateTime": fields.Int(required=True, load_from="UpdateTime"),
        "VSID": fields.Str(required=True, load_from="VSID"),
    }


class VSInfoSchema(schema.ResponseSchema):
    """VSInfo - VServer信息"""

    fields = {
        "AlarmTemplateID": fields.Str(
            required=True, load_from="AlarmTemplateID"
        ),
        "CACertificateID": fields.Str(
            required=False, load_from="CACertificateID"
        ),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "Domain": fields.Str(required=False, load_from="Domain"),
        "HealthcheckType": fields.Str(
            required=True, load_from="HealthcheckType"
        ),
        "KeepaliveTimeout": fields.Int(
            required=True, load_from="KeepaliveTimeout"
        ),
        "LBID": fields.Str(required=True, load_from="LBID"),
        "Path": fields.Str(required=False, load_from="Path"),
        "PersistenceKey": fields.Str(
            required=False, load_from="PersistenceKey"
        ),
        "PersistenceType": fields.Str(
            required=True, load_from="PersistenceType"
        ),
        "Port": fields.Int(required=True, load_from="Port"),
        "Protocol": fields.Str(required=True, load_from="Protocol"),
        "RSHealthStatus": fields.Str(required=True, load_from="RSHealthStatus"),
        "RSInfos": fields.List(RSInfoSchema()),
        "SSLMode": fields.Str(required=False, load_from="SSLMode"),
        "Scheduler": fields.Str(required=True, load_from="Scheduler"),
        "ServerCertificateID": fields.Str(
            required=False, load_from="ServerCertificateID"
        ),
        "UpdateTime": fields.Int(required=True, load_from="UpdateTime"),
        "VSID": fields.Str(required=True, load_from="VSID"),
        "VSPolicyInfos": fields.List(VSPolicyInfoSchema()),
        "VSStatus": fields.Str(required=True, load_from="VSStatus"),
    }


class PriceInfoSchema(schema.ResponseSchema):
    """PriceInfo - 价格信息"""

    fields = {
        "ChargeType": fields.Str(required=True, load_from="ChargeType"),
        "Price": fields.Float(required=True, load_from="Price"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.udts.schemas import apis


class UDTSClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(UDTSClient, self).__init__(config, transport, middleware, logger)

    def check_udts_task(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CheckUDTSTask - 对UDTS 任务提供预检查功能

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **MaxRetryCount** (str) - (Required) 重试次数，最大为 5。 默认为0
        - **Name** (str) - (Required) task 名称，长度不能超过 128
        - **Type** (str) - (Required) 任务类型，值为 transfer 或 integration， transfer 时任务为 数据迁移，integration 时任务为 数据集成。
        - **Query** (str) - 废弃
        - **Source** (list) - 见 **CheckUDTSTaskParamSource** 模型定义
        - **Target** (dict) - 见 **CheckUDTSTaskParamTarget** 模型定义

        **Response**

        - **Action** (str) - 操作名称
        - **Data** (dict) - 见 **CheckUDTSTaskResult** 模型定义
        - **Message** (str) - 返回消息
        - **RetCode** (str) - 返回码

        **Request Model**

        **CheckUDTSTaskParamSourceMySQLNodeSyncData**
        - **BinlogGTID** (str) - 增量时需要指定的 binlog gtid，可以通过 show master status 获取，或者全量+增量任务会自动设置
        - **BinlogName** (str) - 增量时需要指定的 binlog name，可以通过 show master status 获取，或者全量+增量任务会自动设置
        - **BinlogPos** (int) - 增量时需要指定的 binlog pos，可以通过 show master status 获取，或者全量+增量任务会自动设置
        - **ServerID** (int) - 增量时需要指定的 serverID，不能和现有的 slave 重复，预检查时会检查该值


        **CheckUDTSTaskParamSourceMySQLNodeQueryData**
        - **DBName** (str) - 数据集成时需要迁移的 DB 名
        - **NewDBName** (str) - 数据集成时迁移后的 DB 名


        **CheckUDTSTaskParamTargetMySQLNode**
        - **DataRegion** (str) - 目标数据库地域，比如 cn-bj2
        - **Host** (str) - 目标数据库地址， 比如 10.9.37.212
        - **Password** (str) - 目标数据库密码
        - **Port** (int) - 目标数据库端口，比如 3306
        - **SubnetId** (str) - 目标数据库子网 ID ,比如 subnet-zl44fktq
        - **User** (str) - 目标数据库用户名，比如 root
        - **VPCId** (str) - 目标数据库 VPC,比如 uvnet-1wz5rqte


        **CheckUDTSTaskParamSourceMySQLNode**
        - **DataRegion** (str) - 数据库地域，比如 cn-bj2
        - **Database** (str) - 需要迁移的 DB 名称
        - **Host** (str) - 源数据库地址， 比如 10.9.37.200
        - **Password** (str) - 源 MySQL 密码
        - **Port** (int) - 源 MySQL 端口，如 3306
        - **QueryData** (list) - 见 **CheckUDTSTaskParamSourceMySQLNodeQueryData** 模型定义
        - **SubnetId** (str) - 子网 ID
        - **SyncData** (dict) - 见 **CheckUDTSTaskParamSourceMySQLNodeSyncData** 模型定义
        - **Table** (str) - 需要迁移的 table 名
        - **User** (str) - 源 MySQL 用户名，如 root
        - **VPCId** (str) - VPC


        **CheckUDTSTaskParamTarget**
        - **DataType** (str) - 目标数据库类型，比如 mysql
        - **MySQLNode** (dict) - 见 **CheckUDTSTaskParamTargetMySQLNode** 模型定义
        - **NWType** (str) - 目标 db 网络类型，目前进支持 user


        **CheckUDTSTaskParamSource**
        - **DataType** (str) - 数据库类型
        - **Mode** (str) - // 任务类型，值可以是 full, incremental, full+incremental, bidirectional
        - **MySQLNode** (dict) - 见 **CheckUDTSTaskParamSourceMySQLNode** 模型定义
        - **NWType** (str) - 源网络类型，可以是 public,user,dedicated_line


        **Response Model**

        **CheckResultItem**
        - **ErrMessage** (str) -
        - **State** (str) - 状态


        **CheckResult**
        - **Config** (dict) - 见 **CheckResultItem** 模型定义
        - **Connection** (dict) - 见 **CheckResultItem** 模型定义
        - **Privileges** (dict) - 见 **CheckResultItem** 模型定义


        **CheckUDTSTaskResult**
        - **Source** (dict) - 见 **CheckResult** 模型定义
        - **Target** (dict) - 见 **CheckResult** 模型定义


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.CheckUDTSTaskRequestSchema().dumps(d)

        resp = self.invoke("CheckUDTSTask", d, **kwargs)
        return apis.CheckUDTSTaskResponseSchema().loads(resp)

    def create_udts_task(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUDTSTask - 创建UDTS任务

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Name** (str) - (Required) task 名称，长度不能超过 128
        - **Type** (str) - (Required) 任务类型，transfer(数据传输) 或 integration(数据集成)
        - **IsUnidirection** (str) - 暂时未使用该字段
        - **MaxRetryCount** (str) - 重试次数，最大为 5。 默认为0
        - **Query** (str) - 暂时未使用该字段
        - **Remark** (str) - 备注信息，长度不能大于 255
        - **Source** (list) - 见 **CreateUDTSTaskParamSource** 模型定义
        - **Target** (dict) - 见 **CreateUDTSTaskParamTarget** 模型定义

        **Response**

        - **Data** (dict) -
        - **Message** (str) - 返回消息

        **Request Model**

        **CreateUDTSTaskParamSourceMySQLNodeQueryDataTableData**
        - **ExcludeTables** (bool) - 暂时未使用该字段
        - **TableNames** (str) - 暂时未使用该字段


        **CreateUDTSTaskParamSourceMySQLNodeQueryDataTableMaps**
        - **NewTableName** (str) - 数据集成时迁移后的 Table 名
        - **TableName** (str) - 数据集成时需要迁移的 Table 名


        **CreateUDTSTaskParamSourceMySQLNodeSyncData**
        - **BinlogGTID** (str) - 增量时需要指定的 binlog gtid，可以通过 show master status 获取，或者全量+增量任务会自动设置
        - **BinlogName** (str) - 增量时需要指定的 binlog name，可以通过 show master status 获取，或者全量+增量任务会自动设置
        - **BinlogPos** (int) - 增量时需要指定的 binlog pos，可以通过 show master status 获取，或者全量+增量任务会自动设置
        - **ServerID** (int) - 增量时需要指定的 serverID，不能和现有的 slave 重复，预检查时会检查该值


        **CreateUDTSTaskParamSourceMySQLNodeQueryData**
        - **DBName** (str) - 数据集成时需要迁移的 DB 名
        - **NewDBName** (str) - 数据集成时迁移后的 DB 名
        - **TableData** (dict) - 见 **CreateUDTSTaskParamSourceMySQLNodeQueryDataTableData** 模型定义
        - **TableMaps** (list) - 见 **CreateUDTSTaskParamSourceMySQLNodeQueryDataTableMaps** 模型定义


        **CreateUDTSTaskParamSourceMySQLNode**
        - **DataRegion** (str) - 数据库地域，比如 cn-bj2
        - **Database** (str) - 需要迁移的 DB 名称
        - **DupAction** (str) - 重复数据处理规则，数据集成时该参数才有效，值为 ignore或者replace
        - **Host** (str) - 源数据库地址
        - **KeepExistData** (bool) - 是否保留原有数据，只有数据集成时该参数才有效
        - **Password** (str) - 源数据库密码
        - **Port** (int) - 源数据库端口
        - **QueryData** (list) - 见 **CreateUDTSTaskParamSourceMySQLNodeQueryData** 模型定义
        - **SubnetId** (str) - 源数据库子网 ID，当网络类型为 user 时需要填写
        - **SyncData** (dict) - 见 **CreateUDTSTaskParamSourceMySQLNodeSyncData** 模型定义
        - **Table** (str) - 需要迁移的 table 名
        - **User** (str) - 源数据库用户名
        - **VPCId** (str) - 源数据库 VPC ID，当网络类型为 user 时需要填写


        **CreateUDTSTaskParamTargetMySQLNode**
        - **DataRegion** (str) - 目标数据库地域，比如 cn-bj2
        - **Host** (str) - 目标数据库地址， 比如 10.9.37.212
        - **NoBinlog** (bool) - 是否在全量过程中，临时禁用目标 MySQL 产生 binlog，在目标磁盘空间不足，或者需要获取更快的迁移速度时可以使用，该参数会破坏目标 MySQL 的高可用
        - **Password** (str) - 目标数据库密码
        - **Port** (int) - 目标数据库端口，比如 3306
        - **SubnetId** (str) - 目标数据库子网 ID ,比如 subnet-zl44fktq
        - **User** (str) - 目标数据库用户名，比如 root
        - **VPCId** (str) - 目标数据库 VPC,比如 uvnet-1wz5rqte


        **CreateUDTSTaskParamSource**
        - **BandwidthLimit** (int) - 源端限速值，单位为  MB/s
        - **DataType** (str) - 数据库类型，比如 mysql
        - **Mode** (str) - 任务类型，值可以是 full, incremental, full+incremental, bidirectional
        - **MySQLNode** (dict) - 见 **CreateUDTSTaskParamSourceMySQLNode** 模型定义
        - **NWType** (str) - 源网络类型，可以是 public,user,dedicated_line


        **CreateUDTSTaskParamTarget**
        - **BandwidthLimit** (str) - 目标端限速，单位为 MB/s
        - **DataType** (str) - 目标数据库类型，比如 mysql
        - **Mode** (str) -
        - **MySQLNode** (dict) - 见 **CreateUDTSTaskParamTargetMySQLNode** 模型定义
        - **NWType** (str) - 目标 db 网络类型，目前仅支持 user


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.CreateUDTSTaskRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUDTSTask", d, **kwargs)
        return apis.CreateUDTSTaskResponseSchema().loads(resp)

    def get_udts_task_history(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUDTSTaskHistory - 获取任务历史状态

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **TaskId** (str) - (Required) 任务短 id
        - **Type** (str) - 任务类型

        **Response**

        - **Data** (list) - 见 **TaskHistoryItem** 模型定义

        **Response Model**

        **TaskHistoryItem**
        - **AntID** (str) - 任务 ID
        - **AntState** (str) - 任务状态
        - **CreateTime** (int) - 事件时间，值为 timestamp
        - **CreateTimeH** (str) - 事件时间，为可读的日期时间


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.GetUDTSTaskHistoryRequestSchema().dumps(d)

        resp = self.invoke("GetUDTSTaskHistory", d, **kwargs)
        return apis.GetUDTSTaskHistoryResponseSchema().loads(resp)

    def get_udts_task_status(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUDTSTaskStatus - 查看服务状态

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **TaskId** (str) - (Required) 任务ID
        - **Type** (str) - 任务类型，值为 transfer 或 integration， transfer 时任务为 数据迁移，integration 时任务为 数据集成。

        **Response**

        - **Data** (dict) - 见 **StatusData** 模型定义
        - **Message** (str) - 返回信息

        **Response Model**

        **SyncData**
        - **BinlogGTID** (str) - GTID
        - **BinlogName** (str) - Binlog 文件名， 长度不超过128字符
        - **BinlogPos** (int) - Binlog Pos
        - **ServerId** (int) - 分配给UDTS task的server ID, 必须在MySQL集群中唯一


        **Progress**
        - **CurCount** (int) - 已迁移条目数
        - **CurDuration** (int) - 已耗时间（单位秒）
        - **Percentage** (float) - 完成进度
        - **TotalCount** (int) - 总条目数
        - **TotalDuration** (int) - 估算总耗时间（单位秒）


        **StatusData**
        - **CurRetryCount** (int) - 当前失败重试次数
        - **FailedMessage** (str) - 当Status为Failed时, 显示失败原因
        - **MaxRetryCount** (int) - 用户设置的最大失败重试次数
        - **Progress** (dict) - 见 **Progress** 模型定义
        - **Status** (str) - 任务状态, 状态有 Created:已创建,Checking:检查中,Dumping:转储中,Loading:加载中,Syncing:同步中,Synced:已同步,Done:完成,Failed:失败,Stopping:停止中,Stopped:停止,RetryPending:重试等待中,Starting:启动中,FailedUnrecoverable:异常,StoppedUnrecoverable:异常,Success:成功,Started:已启动
        - **Sync** (dict) - 见 **SyncData** 模型定义


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.GetUDTSTaskStatusRequestSchema().dumps(d)

        resp = self.invoke("GetUDTSTaskStatus", d, **kwargs)
        return apis.GetUDTSTaskStatusResponseSchema().loads(resp)

    def list_udts_task(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ListUDTSTask - 获取用户创建的 Task 信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Limit** (str) - 请求数量，默认为 20
        - **Offset** (str) - 偏移量，默认为 0
        - **Type** (str) - 任务类型

        **Response**

        - **Data** (list) - 见 **ListDataItem** 模型定义
        - **Message** (str) - 返回信息

        **Response Model**

        **Progress**
        - **CurCount** (int) - 已迁移条目数
        - **CurDuration** (int) - 已耗时间（单位秒）
        - **Percentage** (float) - 完成进度
        - **TotalCount** (int) - 总条目数
        - **TotalDuration** (int) - 估算总耗时间（单位秒）


        **ListDataItem**
        - **CreateTime** (int) - 创建时间
        - **CurRetryCount** (int) - 当前失败重试次数
        - **MaxRetryCount** (int) - 最大失败重试次数
        - **Name** (str) - 任务名称
        - **Progress** (dict) - 见 **Progress** 模型定义
        - **Status** (str) - 任务状态
        - **TaskId** (str) - 任务 ID
        - **Type** (str) - 任务类型, full全量, incremental增量，full+incremental全量+增量。


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.ListUDTSTaskRequestSchema().dumps(d)

        resp = self.invoke("ListUDTSTask", d, **kwargs)
        return apis.ListUDTSTaskResponseSchema().loads(resp)

    def start_udts_task(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """StartUDTSTask - 启动UDTS服务

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **TaskId** (str) - (Required) 任务ID
        - **Type** (str) - 任务类型

        **Response**

        - **Message** (str) - 返回信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.StartUDTSTaskRequestSchema().dumps(d)

        resp = self.invoke("StartUDTSTask", d, **kwargs)
        return apis.StartUDTSTaskResponseSchema().loads(resp)

    def stop_udts_task(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """StopUDTSTask - 停止UDTS任务

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **TaskId** (str) - (Required) 任务 ID
        - **Type** (str) - 任务类型

        **Response**

        - **Message** (str) - 返回信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.StopUDTSTaskRequestSchema().dumps(d)

        resp = self.invoke("StopUDTSTask", d, **kwargs)
        return apis.StopUDTSTaskResponseSchema().loads(resp)



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class UFileTokenSetSchema(schema.ResponseSchema):
    """UFileTokenSet - ufile令牌集合"""

    fields = {
        "AllowedBuckets": fields.List(fields.Str()),
        "AllowedOps": fields.List(fields.Str()),
        "AllowedPrefixes": fields.List(fields.Str()),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "ExpireTime": fields.Int(required=True, load_from="ExpireTime"),
        "ModifyTime": fields.Int(required=True, load_from="ModifyTime"),
        "PrivateKey": fields.Str(required=True, load_from="PrivateKey"),
        "PublicKey": fields.Str(required=True, load_from="PublicKey"),
        "Region": fields.Str(required=True, load_from="Region"),
        "TokenId": fields.Str(required=True, load_from="TokenId"),
        "TokenName": fields.Str(required=True, load_from="TokenName"),
    }


class UFileDomainSetSchema(schema.ResponseSchema):
    """UFileDomainSet - DescribeBucket"""

    fields = {
        "Cdn": fields.List(fields.Str()),
        "CustomCdn": fields.List(fields.Str()),
        "CustomSrc": fields.List(fields.Str()),
        "Src": fields.List(fields.Str()),
    }


class UFileBucketSetSchema(schema.ResponseSchema):
    """UFileBucketSet - DescribeBucket"""

    fields = {
        "Biz": fields.Str(required=False, load_from="Biz"),
        "BucketId": fields.Str(required=False, load_from="BucketId"),
        "BucketName": fields.Str(required=False, load_from="BucketName"),
        "CdnDomainId": fields.List(fields.Str()),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "Domain": UFileDomainSetSchema(),
        "HasUserDomain": fields.Int(required=False, load_from="HasUserDomain"),
        "ModifyTime": fields.Int(required=False, load_from="ModifyTime"),
        "Region": fields.Str(required=False, load_from="Region"),
        "Tag": fields.Str(required=False, load_from="Tag"),
        "Type": fields.Str(required=False, load_from="Type"),
    }


class LifeCycleItemSchema(schema.ResponseSchema):
    """LifeCycleItem - 生命周期信息"""

    fields = {
        "ArchivalDays": fields.Int(required=False, load_from="ArchivalDays"),
        "BucketName": fields.Str(required=False, load_from="BucketName"),
        "Days": fields.Int(required=False, load_from="Days"),
        "IADays": fields.Int(required=False, load_from="IADays"),
        "LifeCycleId": fields.Str(required=False, load_from="LifeCycleId"),
        "LifeCycleName": fields.Str(required=False, load_from="LifeCycleName"),
        "Prefix": fields.Str(required=False, load_from="Prefix"),
        "Status": fields.Str(required=False, load_from="Status"),
    }


class UFileTotalReportItemSchema(schema.ResponseSchema):
    """UFileTotalReportItem - 总消费信息"""

    fields = {
        "ApiTimes": fields.Float(required=False, load_from="ApiTimes"),
        "BusyFlow": fields.Float(required=False, load_from="BusyFlow"),
        "CdnFlow": fields.Float(required=False, load_from="CdnFlow"),
        "Flow": fields.Float(required=False, load_from="Flow"),
        "IdleFlow": fields.Float(required=False, load_from="IdleFlow"),
    }


class UFileDailyReportItemSchema(schema.ResponseSchema):
    """UFileDailyReportItem -"""

    fields = {
        "AcRestore": fields.Float(required=False, load_from="AcRestore"),
        "AcStorage": fields.Float(required=False, load_from="AcStorage"),
        "ApiTimes": fields.Float(required=False, load_from="ApiTimes"),
        "BusyFlow": fields.Float(required=False, load_from="BusyFlow"),
        "CdnFlow": fields.Float(required=False, load_from="CdnFlow"),
        "Date": fields.Int(required=False, load_from="Date"),
        "Flow": fields.Float(required=False, load_from="Flow"),
        "IaGetSize": fields.Float(required=False, load_from="IaGetSize"),
        "IaStorage": fields.Float(required=False, load_from="IaStorage"),
        "IdleFlow": fields.Float(required=False, load_from="IdleFlow"),
        "Storage": fields.Float(required=False, load_from="Storage"),
    }


class UFileReportItemSchema(schema.ResponseSchema):
    """UFileReportItem -"""

    fields = {
        "Daily": fields.List(UFileDailyReportItemSchema()),
        "Total": fields.List(UFileTotalReportItemSchema()),
    }


class UFileQuotaLeftSchema(schema.ResponseSchema):
    """UFileQuotaLeft - 配额剩余量"""

    fields = {
        "Left": fields.Float(required=False, load_from="Left"),
    }


class UFileQuotaDataSetItemSchema(schema.ResponseSchema):
    """UFileQuotaDataSetItem - 配额信息"""

    fields = {
        "DownloadFlow": UFileQuotaLeftSchema(),
        "Owe": fields.Int(required=False, load_from="Owe"),
        "Region": fields.Str(required=False, load_from="Region"),
        "RequestCnt": UFileQuotaLeftSchema(),
        "Storage": UFileQuotaLeftSchema(),
    }


class UFileReportSetSchema(schema.ResponseSchema):
    """UFileReportSet - GetUFileReport"""

    fields = {
        "DownloadTraffic": fields.Float(
            required=False, load_from="DownloadTraffic"
        ),
        "RequestCount": fields.Float(required=False, load_from="RequestCount"),
        "StorageVolume": fields.Float(
            required=False, load_from="StorageVolume"
        ),
        "Time": fields.Int(required=False, load_from="Time"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.usms.schemas import apis


class USMSClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(USMSClient, self).__init__(config, transport, middleware, logger)

    def create_usms_signature(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUSMSSignature - 调用接口CreateUSMSSignature申请短信签名

        **Request**

        - **ProjectId** (str) - (Config) 项目ID，不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **CertificateType** (int) - (Required) 签名的资质证明文件类型，需与签名类型保持一致，说明如下：0-三证合一/企业营业执照/组织机构代码证书/社会信用代码证书；1-应用商店后台开发者管理截图；2-备案服务商的备案成功截图(含域名，网站名称，备案号)；3-公众号或小程序的管理界面截图；4-商标注册证书；5-组织机构代码证书、社会信用代码证书；
        - **Description** (str) - (Required) 短信签名申请原因
        - **File** (str) - (Required) 短信签名的资质证明文件，需先进行base64编码格式转换，此处填写转换后的字符串。文件大小不超过4 MB
        - **SigContent** (str) - (Required) 签名内容
        - **SigPurpose** (int) - (Required) 签名用途，0-自用，1-他用；
        - **SigType** (int) - (Required) 签名类型，说明如下：0-公司或企业的全称或简称；1-App应用的全称或简称；2-工信部备案网站的全称或简称；3-公众号或小程序的全称或简称；4-商标名的全称或简称；5-政府/机关事业单位/其他单位的全称或简称；
        - **International** (bool) - 国内/国际短信。true:国际短信，false:国内短信，若不传值则默认该值为false
        - **ProxyFile** (str) - 短信签名授权委托文件，需先进行base64编码格式转换，此处填写转换后的字符串。文件大小不超过4 MB；当您是代理并使用第三方的签名时（也即SigPurpose为1-他用），该项为必填项；

        **Response**

        - **Message** (str) - 返回状态码描述，如果操作成功，默认返回为空
        - **SigId** (str) - 短信签名ID（短信签名申请时的工单ID）

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.CreateUSMSSignatureRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUSMSSignature", d, **kwargs)
        return apis.CreateUSMSSignatureResponseSchema().loads(resp)

    def create_usms_template(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateUSMSTemplate - 调用接口CreateUSMSTemplate申请短信模板

        **Request**

        - **ProjectId** (str) - (Config) 项目ID，不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Purpose** (int) - (Required) 短信模板用途类型：1-验证码类短信模板；2-系统通知类短信模板；3-会员推广类短信模板；
        - **Template** (str) - (Required) 短信模板内容，说明如下：字数不超过500，每个中文、符号、英文、数组等都计为一个字；模板中的变量填写格式：{N}，其中N为大于1的整数，有多个参数时，建议N从1开始顺次，例如：{1}、{2}等；短信模板禁止仅包括变量的情况；
        - **TemplateName** (str) - (Required) 短信模板名称，不超过32个字符，每个中文、符号、英文、数字等都计为1个字。
        - **Instruction** (str) - 模板变量属性说明
        - **International** (bool) - 标记是否为国际短信。true:国际短信，false:国内短信，若不传值则默认该值为false
        - **Remark** (str) - 短信模板申请原因说明，字数不超过128，每个中文、符号、英文、数字等都计为1个字。
        - **UnsubscribeInfo** (str) - 当Purpose为3时，也即会员推广类短信模板，该项必填。枚举值：TD退订、回T退订、回N退订、回TD退订、退订回T、退订回D、退订回TD、退订回复T、退订回复D、退订回复N、退订回复TD、拒收回T

        **Response**

        - **Message** (str) - 返回状态码描述，如果操作成功，默认返回为空
        - **TemplateId** (str) - 短信模板ID（短信模板申请时的工单ID）

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.CreateUSMSTemplateRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUSMSTemplate", d, **kwargs)
        return apis.CreateUSMSTemplateResponseSchema().loads(resp)

    def delete_usms_signature(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUSMSSignature - 调用接口DeleteUSMSSignature删除短信签名

        **Request**

        - **ProjectId** (str) - (Config) 项目ID，不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **SigIds** (list) - (Required) 签名ID（也即短信签名申请时的工单ID），支持以数组的方式，举例，以SigIds.0、SigIds.1...SigIds.N方式传入

        **Response**

        - **Message** (str) - 返回状态码描述，如果操作成功，默认返回为空

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DeleteUSMSSignatureRequestSchema().dumps(d)

        resp = self.invoke("DeleteUSMSSignature", d, **kwargs)
        return apis.DeleteUSMSSignatureResponseSchema().loads(resp)

    def delete_usms_template(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteUSMSTemplate - 调用接口DeleteUSMSTemplate删除短信模板

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist.html>`_
        - **TemplateIds** (list) - (Required) 模板ID（也即短信模板申请时的工单ID），支持以数组的方式，举例，以TemplateIds.0、TemplateIds.1...TemplateIds.N方式传入

        **Response**

        - **Message** (str) - 返回状态码描述，如果操作成功，默认返回为空

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.DeleteUSMSTemplateRequestSchema().dumps(d)

        resp = self.invoke("DeleteUSMSTemplate", d, **kwargs)
        return apis.DeleteUSMSTemplateResponseSchema().loads(resp)

    def get_usms_send_receipt(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """GetUSMSSendReceipt - 调用接口GetUSMSSendReceipt短信发送状态信息

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **SessionNoSet** (list) - (Required) 发送短信时返回的SessionNo集合，SessionNoSet.0,SessionNoSet.1....格式，单次调用集合数需控制在100个以内
        - **Zone** (str) - 可用区。参见  `可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_

        **Response**

        - **Data** (list) - 见 **ReceiptPerSession** 模型定义
        - **Message** (str) - 错误描述

        **Response Model**

        **ReceiptPerSession**
        - **ReceiptSet** (list) - 见 **ReceiptPerPhone** 模型定义
        - **SessionNo** (str) - 发送短信时返回的SessionNo


        **ReceiptPerPhone**
        - **CostCount** (int) - 消耗短信条数
        - **Phone** (str) - 手机号码
        - **ReceiptCode** (str) - 状态报告编码
        - **ReceiptDesc** (str) - 回执结果描述
        - **ReceiptResult** (str) - 回执结果，枚举值：\\ > 发送成功: 代表成功 \\ > Success: 代表成功 \\ > 发送失败: 代表失败 \\ > Fail: 代表失败 \\ > 状态未知: 代表未知 \\ > Unknow: 代表未知
        - **ReceiptTime** (int) - 回执返回时间
        - **UserId** (str) - 自定义的业务标识ID，字符串


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.GetUSMSSendReceiptRequestSchema().dumps(d)

        resp = self.invoke("GetUSMSSendReceipt", d, **kwargs)
        return apis.GetUSMSSendReceiptResponseSchema().loads(resp)

    def query_usms_signature(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """QueryUSMSSignature - 调用接口QueryUSMSSignature查询短信签名申请状态

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list.html>`_
        - **SigContent** (str) - 签名内容；签名ID和签名至少需填写1项；
        - **SigId** (str) - 已申请的短信签名ID（短信签名申请时的工单ID）；签名ID和签名至少需填写1项；

        **Response**

        - **Data** (dict) - 见 **OutSignature** 模型定义
        - **Message** (str) - 发生错误时，表示具体错误描述

        **Response Model**

        **OutSignature**
        - **ErrDesc** (str) - 签名审核失败原因
        - **SigContent** (str) - 签名内容
        - **SigId** (str) - 签名ID
        - **Status** (int) - 签名状态。0-待审核 1-审核中 2-审核通过 3-审核未通过 4-被禁用


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.QueryUSMSSignatureRequestSchema().dumps(d)

        resp = self.invoke("QueryUSMSSignature", d, **kwargs)
        return apis.QueryUSMSSignatureResponseSchema().loads(resp)

    def query_usms_template(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """QueryUSMSTemplate - 调用接口QueryUSMSTemplate查询短信模板申请状态

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **TemplateId** (str) - (Required) 模板ID

        **Response**

        - **Data** (dict) - 见 **OutTemplate** 模型定义
        - **Message** (str) - 当RetCode不为0时，Message中显示具体错误描述

        **Response Model**

        **OutTemplate**
        - **CreateTime** (int) - 创建时间
        - **ErrDesc** (str) - 审核失败原因
        - **Instruction** (str) - 模板变量属性说明
        - **Purpose** (int) - 模板类型，选项：1-验证码类 2-通知类 3-会员推广类
        - **Remark** (str) - 模板说明
        - **Status** (int) - 短信模板状态；状态说明：0-待审核，1-审核中，2-审核通过，3-审核未通过，4-被禁用
        - **Template** (str) - 短信模板内容
        - **TemplateId** (str) - 短信模板ID
        - **TemplateName** (str) - 短信模板名称
        - **UnsubscribeInfo** (str) - 退订信息；一般填写方式“回T退订”，当purpose为3（也即会员推广类）时，为必填项


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.QueryUSMSTemplateRequestSchema().dumps(d)

        resp = self.invoke("QueryUSMSTemplate", d, **kwargs)
        return apis.QueryUSMSTemplateResponseSchema().loads(resp)

    def send_batch_usms_message(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """SendBatchUSMSMessage - 调用SendBatchUSMSMessage接口批量发送短信

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **TaskContent** (str) - (Required) 批量发送内容，该参数是json数组的base64编码结果。发送内容json数组中，每个“模板+签名”组合作为一个子项，每个子项内支持多个号码，示例：发送内容json数组（base64编码前）：[{"TemplateId": "UTA20212831C85C", "SigContent": "UCloud", "Target": [{"TemplateParams": ["123456"], "Phone": "18500000123", "ExtendCode": "123", "UserId": "456"} ] } ]   。json数组中各参数的定义："TemplateId":模板ID，"SigContent"短信签名内容，"Target"具体到号码粒度的发送内容。"Target"中的具体字段有："TemplateParams"实际发送的模板参数（若使用的是无参数模板，该参数不能传值），"Phone"手机号码, "ExtendCode"短信扩展码, "UserId"自定义业务标识ID。其中必传参数为"TemplateId", "SigContent", "Target"（"Target"中必传参数为"Phone"）。实际调用本接口时TaskContent传值（发送内容base64编码后）为：W3siVGVtcGxhdGVJZCI6ICJVVEEyMDIxMjgzMUM4NUMiLCAiU2lnQ29udGVudCI6ICJVQ2xvdWQiLCAiVGFyZ2V0IjogW3siVGVtcGxhdGVQYXJhbXMiOiBbIjEyMzQ1NiJdLCAiUGhvbmUiOiAiMTg1MDAwMDAxMjMiLCAiRXh0ZW5kQ29kZSI6ICIxMjMiLCAiVXNlcklkIjogIjQ1NiJ9IF0gfSBdIA==

        **Response**

        - **FailContent** (list) - 见 **BatchInfo** 模型定义
        - **Message** (str) - 发生错误时表示错误描述
        - **ReqUuid** (str) - 本次请求Uuid
        - **SessionNo** (str) - 本次提交发送任务的唯一ID，可根据该值查询本次发送的短信列表。注：成功提交短信数大于0时，才返回该字段
        - **SuccessCount** (int) - 成功提交短信（未拆分）条数

        **Response Model**

        **BatchInfo**
        - **FailureDetails** (str) - 未能成功发送的详情。注：模板/签名检验失败时，该字段有效
        - **SigContent** (str) - 签名
        - **Target** (list) - 见 **FailPhoneDetail** 模型定义
        - **TemplateId** (str) - 模板ID


        **FailPhoneDetail**
        - **ExtendCode** (str) - 扩展号码
        - **FailureDetails** (str) - 发送失败原因。注：若模板/签名校验失败，该字段为空
        - **Phone** (str) - 手机号
        - **TemplateParams** (list) - 模板参数
        - **UserId** (str) - 用户自定义ID


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.SendBatchUSMSMessageRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("SendBatchUSMSMessage", d, **kwargs)
        return apis.SendBatchUSMSMessageResponseSchema().loads(resp)

    def send_usms_message(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """SendUSMSMessage - 调用接口SendUSMSMessage发送短信

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **PhoneNumbers** (list) - (Required) 电话号码数组，电话号码格式为(60)1xxxxxxxx，()中为国际长途区号(如中国为86或0086，两种格式都支持)，后面为电话号码.若不传入国际区号，如1851623xxxx，则默认为国内手机号
        - **SigContent** (str) - (Required) 短信签名内容，请到 `USMS控制台 <https://console.ucloud.cn/usms>`_ 的签名管理页面查看；使用的短信签名必须是已申请并且通过审核；
        - **TemplateId** (str) - (Required) 模板ID（也即短信模板申请时的工单ID），请到 `USMS控制台 <https://console.ucloud.cn/usms>`_ 的模板管理页面查看；使用的短信模板必须是已申请并通过审核；
        - **ExtendCode** (str) - 短信扩展码，格式为阿拉伯数字串，默认不开通，如需开通请联系 UCloud技术支持
        - **TemplateParams** (list) - 模板可变参数，以数组的方式填写，举例，TemplateParams.0，TemplateParams.1，... 若模板中无可变参数，则该项可不填写；若模板中有可变参数，则该项为必填项，参数个数需与变量个数保持一致，否则无法发送；
        - **UserId** (str) - 自定义的业务标识ID，字符串（ 长度不能超过32 位），不支持 单引号、表情包符号等特殊字符

        **Response**

        - **Message** (str) - 发生错误时表示错误描述
        - **SessionNo** (str) - 本次提交发送的短信的唯一ID，可根据该值查询本次发送的短信列表
        - **UserId** (str) - 本次提交的自定义业务标识ID，仅当发送时传入有效的UserId，才返回该字段。

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.SendUSMSMessageRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("SendUSMSMessage", d, **kwargs)
        return apis.SendUSMSMessageResponseSchema().loads(resp)

    def update_usms_signature(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UpdateUSMSSignature - 调用接口UpdateUSMSSignature修改未通过审核的短信签名，并重新提交审核

        **Request**

        - **ProjectId** (str) - (Config) 项目ID，不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **SigContent** (str) - (Required) 新的短信签名内容；长度为2-12个字符, 可包含中文、数字和符号；无需填写【】或[]，系统会自动添加
        - **SigId** (str) - (Required) 签名ID（也即短信签名申请时的工单ID），支持以数组的方式，举例，以SigIds.0、SigIds.1...SigIds.N方式传入
        - **SigPurpose** (int) - (Required) 签名用途，0-自用，1-他用；
        - **SigType** (int) - (Required) 签名类型，说明如下：0-公司或企业的全称或简称；1-App应用的全称或简称；2-工信部备案网站的全称或简称；3-公众号或小程序的全称或简称；4-商标名的全称或简称；5-政府/机关事业单位/其他单位的全称或简称；
        - **CertificateType** (int) - 签名的资质证明文件类型，需与签名类型保持一致，说明如下：0-三证合一/企业营业执照/组织机构代码证书/社会信用代码证书；1-应用商店后台开发者管理截图；2-备案服务商的备案成功截图(含域名，网站名称，备案号)；3-公众号或小程序的管理界面截图；4-商标注册证书；5-组织机构代码证书、社会信用代码证书；
        - **Document** (str) - 短信签名的资质证明文件URL，若未更改审核材料，则该处使用已上传审核材料的URL链接，否则使用File参数
        - **File** (str) - 短信签名的资质证明文件内容，需先进行base64编码格式转换，此处填写转换后的字符串。文件大小不超过4 MB。内容格式如下: [file type];[code type],[base64]  如：image/jpeg;base64,5YaF5a65
        - **ProxyDoc** (str) - 短信签名授权委托文件URL，若未更改授权委托文件，则该处填写已上传的授权委托文件的URL链接，否则使用ProxyFile参数
        - **ProxyFile** (str) - 短信签名授权委托文件内容，需先进行base64编码格式转换，此处填写转换后的字符串。文件大小不超过4 MB；当您是代理并使用第三方的签名时（也即SigPurpose为1-他用），该项为必填项；格式和File类似。

        **Response**

        - **Message** (str) - 返回状态码描述，如果操作成功，默认返回为空

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.UpdateUSMSSignatureRequestSchema().dumps(d)

        resp = self.invoke("UpdateUSMSSignature", d, **kwargs)
        return apis.UpdateUSMSSignatureResponseSchema().loads(resp)

    def update_usms_template(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UpdateUSMSTemplate - 调用接口UpdateUSMSTemplate修改未通过审核的短信模板，并重新提交审核

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Region** (str) - (Config) 地域。 参见  `地域和可用区列表 <https://docs.ucloud.cn/api/summary/regionlist>`_
        - **Template** (str) - (Required) 新的模板内容。模板名称和模板内容必须提供一个，否则会报错。小于等于600个字
        - **TemplateId** (str) - (Required) 短信模板ID
        - **Instruction** (str) - 模板变量属性说明
        - **Remark** (str) - 短信模板申请原因说明，字数不超过128，每个中文、符号、英文、数字等都计为1个字。
        - **TemplateName** (str) - 新的模板名称。小于等于32个字，每个中文、英文、数组、符合都计为一个字

        **Response**

        - **Message** (str) - 发生错误时表示错误描述

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
            "Region": self.config.region,
        }
        req and d.update(req)
        d = apis.UpdateUSMSTemplateRequestSchema().dumps(d)

        resp = self.invoke("UpdateUSMSTemplate", d, **kwargs)
        return apis.UpdateUSMSTemplateResponseSchema().loads(resp)
